@@ -1,13 +1,17 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper.h
- * Version    : $Id: libipv6calc_db_wrapper.h,v 1.36 2014/10/11 11:17:19 ds6peter Exp $
- * Copyright  : 2013-2014 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: libipv6calc_db_wrapper.h,v 1.43 2015/07/08 06:58:02 ds6peter Exp $
+ * Copyright  : 2013-2015 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file for libipv6calc_db_wrapper.c
  */
 
+#ifdef HAVE_BERKELEY_DB_SUPPORT
+#include <db.h>
+#endif // HAVE_BERKELEY_DB_SUPPORT
+
 #ifndef _libipv6calc_db_wrapper_h
 
 #define _libipv6calc_db_wrapper_h 1
@@ -17,10 +21,6 @@
 #include "libipv4addr.h"
 #include "libipv6addr.h"
 
-#ifdef HAVE_BERKELEY_DB_SUPPORT
-#include <db.h>
-#endif // HAVE_BERKELEY_DB_SUPPORT
-
 extern uint32_t wrapper_features;
 extern uint32_t wrapper_features_by_source[];
 extern uint32_t wrapper_features_by_source_implemented[];
@@ -126,14 +126,15 @@ static const s_formatoption ipv6calc_db_features[] = {
 typedef struct {
 	const int  number;
 	const char *name;
+	const char *shortname;
 } s_data_sources;
 
 static const s_data_sources data_sources[] = {
-	{ IPV6CALC_DB_SOURCE_GEOIP	, "GeoIP"},
-	{ IPV6CALC_DB_SOURCE_IP2LOCATION, "IP2Location"},
-	{ IPV6CALC_DB_SOURCE_DBIP	, "db-ip.com"},
-	{ IPV6CALC_DB_SOURCE_BUILTIN	, "BuiltIn"},
-	{ IPV6CALC_DB_SOURCE_EXTERNAL	, "External"}
+	{ IPV6CALC_DB_SOURCE_GEOIP	, "GeoIP"      , "GeoIP"       },
+	{ IPV6CALC_DB_SOURCE_IP2LOCATION, "IP2Location", "IP2Location" },
+	{ IPV6CALC_DB_SOURCE_DBIP	, "db-ip.com"  , "DBIP"        },
+	{ IPV6CALC_DB_SOURCE_EXTERNAL	, "External"   , "External"    },
+	{ IPV6CALC_DB_SOURCE_BUILTIN	, "BuiltIn"    , "BuiltIn"     },
 };
 
 // database names and descriptions
@@ -144,6 +145,14 @@ typedef struct {
 	const uint32_t     features;
 } db_file_desc;
 
+typedef struct {
+	const unsigned int number;
+	const char        *filename;
+	const char        *description;
+	const uint32_t     features;
+	const uint32_t     internal;
+} db_file_desc2;
+
 
 // define internal API versions
 #define IPV6CALC_DB_API_GEOIP		1
@@ -158,7 +167,7 @@ typedef struct {
 
 // db-info macro
 #define IPV6CALC_DB_FEATURE_INFO(prefix, data_source) \
-        printf("%s%s: features available/implemented: 0x%08x/0x%08x", \
+        fprintf(stderr, "%s%s: features available/implemented: 0x%08x/0x%08x", \
 		prefix, \
 		libipv6calc_db_wrapper_get_data_source_name_by_number(data_source), \
 		wrapper_features_by_source[data_source], \
@@ -167,12 +176,12 @@ typedef struct {
 		int wrapper_features_by_source_bitcount = libipv6calc_bitcount_uint32_t(wrapper_features_by_source[data_source]); \
 		int wrapper_features_by_source_implemented_bitcount = libipv6calc_bitcount_uint32_t(wrapper_features_by_source_implemented[data_source]); \
 		if (wrapper_features_by_source_implemented_bitcount == 0) { \
-			printf(" (NONE)"); \
+			fprintf(stderr, " (NONE)"); \
 		} else { \
-			printf(" (%d%%)", (wrapper_features_by_source_bitcount * 100) / wrapper_features_by_source_implemented_bitcount); \
+			fprintf(stderr, " (%d%%)", (wrapper_features_by_source_bitcount * 100) / wrapper_features_by_source_implemented_bitcount); \
 		}; \
 	}; \
-	printf("\n");
+	fprintf(stderr, "\n");
 
 // AS Number handling
 #define ASNUM_AS_UNKNOWN 0
@@ -228,10 +237,16 @@ typedef struct {
 
 #endif // HAVE_BERKELEY_DB_SUPPORT
 
-#endif
+#define IPV6CALC_DB_LIB_VERSION_CHECK_EXIT(version_numeric, version_string) \
+	if (version_numeric != libipv6calc_db_lib_version_numeric()) { \
+		ERRORPRINT_WA("Database library version is not matching: has:%s required:%s", libipv6calc_db_lib_version_string(), version_string); \
+		exit(1); \
+	};
+
+#endif // _libipv6calc_db_wrapper_h
 
 
-extern int  libipv6calc_db_wrapper_init(void);
+extern int  libipv6calc_db_wrapper_init(const char *prefix_string);
 extern int  libipv6calc_db_wrapper_cleanup(void);
 extern void libipv6calc_db_wrapper_info(char *string, const size_t size);
 extern void libipv6calc_db_wrapper_features(char *string, const size_t size);
@@ -246,8 +261,8 @@ extern const char *libipv6calc_db_wrapper_get_data_source_name_by_number(const i
 /* functional wrappers */
 
 // CountryCode Text/Number
-extern char       *libipv6calc_db_wrapper_country_code_by_addr(const ipv6calc_ipaddr *ipaddrp, unsigned int *data_source_ptr);
-extern int         libipv6calc_db_wrapper_country_code_by_cc_index(char *string, int length, const uint16_t cc_index);
+extern int         libipv6calc_db_wrapper_country_code_by_addr(char *string, const int length, const ipv6calc_ipaddr *ipaddrp, unsigned int *data_source_ptr);
+extern int         libipv6calc_db_wrapper_country_code_by_cc_index(char *string, const int length, const uint16_t cc_index);
 extern uint16_t    libipv6calc_db_wrapper_cc_index_by_addr(const ipv6calc_ipaddr *ipaddrp, unsigned int *data_source_ptr);
 
 // Autonomous System Text/Number
@@ -261,6 +276,8 @@ extern uint32_t    libipv6calc_db_wrapper_as_num32_decomp17(const uint32_t as_nu
 // Registries
 extern int         libipv6calc_db_wrapper_registry_num_by_as_num32(const uint32_t as_num32);
 extern int         libipv6calc_db_wrapper_registry_num_by_cc_index(const uint16_t cc_index);
+extern int         libipv6calc_db_wrapper_registry_num_by_ipaddr(const ipv6calc_ipaddr *ipaddrp);
+extern int         libipv6calc_db_wrapper_registry_string_by_ipaddr(const ipv6calc_ipaddr *ipaddrp, char *resultstring, const size_t resultstring_length);
 
 // IEEE
 extern int libipv6calc_db_wrapper_ieee_vendor_string_by_macaddr(char *resultstring, const size_t resultstring_length, const ipv6calc_macaddr *macaddrp);
@@ -292,3 +309,21 @@ extern long int libipv6calc_db_wrapper_get_entry_generic(
 	void            *data_ptr,		// pointer to DB data in case of IPV6CALC_DB_LOOKUP_DATA_PTR_TYPE_BDB, otherwise NULL
 	int  (*get_array_row)()			// function to get array row
 	);
+
+/* filter powered by database */
+extern int libipv6calc_db_cc_filter_parse(s_ipv6calc_filter_db_cc *filter, const char *token, const int negate_flag);
+extern int libipv6calc_db_cc_filter_check(s_ipv6calc_filter_db_cc *filter, const int proto);
+extern int libipv6calc_db_cc_filter(const uint16_t cc_index, const s_ipv6calc_filter_db_cc *filter);
+
+extern int libipv6calc_db_asn_filter_parse(s_ipv6calc_filter_db_asn *filter, const char *token, const int negate_flag);
+extern int libipv6calc_db_asn_filter_check(s_ipv6calc_filter_db_asn *filter, const int proto);
+extern int libipv6calc_db_asn_filter(const uint32_t asn, const s_ipv6calc_filter_db_asn *filter);
+
+extern int libipv6calc_db_registry_filter_parse(s_ipv6calc_filter_db_registry *filter, const char *token, const int negate_flag);
+extern int libipv6calc_db_registry_filter_check(s_ipv6calc_filter_db_registry *filter, const int proto);
+extern int libipv6calc_db_registry_filter(const int registry, const s_ipv6calc_filter_db_registry *filter);
+
+extern       uint32_t libipv6calc_db_lib_version_numeric(void);
+extern const char    *libipv6calc_db_lib_version_string(void);
+extern       uint32_t libipv6calc_db_api_version_numeric(void);
+extern const char    *libipv6calc_db_api_version_string(void);
