@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_GeoIP.c
- * Version    : $Id: libipv6calc_db_wrapper_GeoIP.c,v 1.72 2015/02/12 07:27:04 ds6peter Exp $
+ * Version    : $Id: libipv6calc_db_wrapper_GeoIP.c,v 1.76 2015/06/10 05:53:57 ds6peter Exp $
  * Copyright  : 2013-2015 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -41,52 +41,42 @@ static const char* wrapper_geoip_info = "dyn-load";
 
 /* define status and dynamic load functions */
 static int dl_status_GeoIP_open = IPV6CALC_DL_STATUS_UNKNOWN;
-//static GeoIP* (*dl_GeoIP_open)(const char * filename, int flags) = NULL;
 typedef GeoIP *(*dl_GeoIP_open_t)(const char * filename, int flags);
 static union { dl_GeoIP_open_t func; void * obj; } dl_GeoIP_open;
 
 static int dl_status_GeoIP_open_type = IPV6CALC_DL_STATUS_UNKNOWN;
-//static GeoIP* (*dl_GeoIP_open_type)(int type, int flags) = NULL;
 typedef GeoIP *(*dl_GeoIP_open_type_t)(int type, int flags);
 static union { dl_GeoIP_open_type_t func; void * obj; } dl_GeoIP_open_type;
 
 static int dl_status_GeoIP_db_avail = IPV6CALC_DL_STATUS_UNKNOWN;
-//static int (*dl_GeoIP_db_avail)(int type) = NULL;
 typedef int (*dl_GeoIP_db_avail_t)(int type);
 static union { dl_GeoIP_db_avail_t func; void * obj; } dl_GeoIP_db_avail;
 
 static int dl_status_GeoIP_database_edition = IPV6CALC_DL_STATUS_UNKNOWN;
-//static unsigned char (*dl_GeoIP_database_edition)(GeoIP* gi) = NULL;
 typedef unsigned char (*dl_GeoIP_database_edition_t)(GeoIP* gi);
 static union { dl_GeoIP_database_edition_t func; void * obj; } dl_GeoIP_database_edition;
 
 static int dl_status_GeoIP_delete = IPV6CALC_DL_STATUS_UNKNOWN;
-//static void (*dl_GeoIP_delete)(GeoIP* gi) = NULL;
 typedef void (*dl_GeoIP_delete_t)(GeoIP* gi);
 static union { dl_GeoIP_delete_t func; void * obj; } dl_GeoIP_delete;
 
 static int dl_status_GeoIP_database_info = IPV6CALC_DL_STATUS_UNKNOWN;
-//static char* (*dl_GeoIP_database_info)(GeoIP* gi) = NULL;
 typedef char *(*dl_GeoIP_database_info_t)(GeoIP* gi);
 static union { dl_GeoIP_database_info_t func; void * obj; } dl_GeoIP_database_info;
 
 static int dl_status_GeoIP_country_code_by_addr = IPV6CALC_DL_STATUS_UNKNOWN;
-//static char* (*dl_GeoIP_country_code_by_addr)(GeoIP* gi, const char *addr) = NULL;
 typedef char *(*dl_GeoIP_country_code_by_addr_t)(GeoIP* gi, const char *addr);
 static union { dl_GeoIP_country_code_by_addr_t func; void * obj; } dl_GeoIP_country_code_by_addr;
 
 static int dl_status_GeoIP_country_name_by_addr = IPV6CALC_DL_STATUS_UNKNOWN;
-//static char* (*dl_GeoIP_country_name_by_addr)(GeoIP* gi, const char *addr) = NULL;
 typedef char *(*dl_GeoIP_country_name_by_addr_t)(GeoIP* gi, const char *addr);
 static union { dl_GeoIP_country_name_by_addr_t func; void * obj; } dl_GeoIP_country_name_by_addr;
 
 static int dl_status_GeoIP_name_by_addr = IPV6CALC_DL_STATUS_UNKNOWN;
-//static char* (*dl_GeoIP_name_by_addr)(GeoIP* gi, const char *addr) = NULL;
 typedef char *(*dl_GeoIP_name_by_addr_t)(GeoIP* gi, const char *addr);
 static union { dl_GeoIP_name_by_addr_t func; void * obj; } dl_GeoIP_name_by_addr;
 
 static int dl_status_GeoIP_record_by_addr = IPV6CALC_DL_STATUS_UNKNOWN;
-//static GeoIPRecord* (*dl_GeoIP_record_by_addr)(GeoIP* gi, const char *addr) = NULL;
 typedef GeoIPRecord *(*dl_GeoIP_record_by_addr_t)(GeoIP* gi, const char *addr);
 static union { dl_GeoIP_record_by_addr_t func; void * obj; } dl_GeoIP_record_by_addr;
 
@@ -95,41 +85,33 @@ typedef GeoIPRecord *(*dl_GeoIP_record_by_addr_v6_t)(GeoIP *gi, const char *addr
 static union { dl_GeoIP_record_by_addr_v6_t func; void * obj; } dl_GeoIP_record_by_addr_v6;
 
 static int dl_status_GeoIPRecord_delete = IPV6CALC_DL_STATUS_UNKNOWN;
-//static void (*dl_GeoIPRecord_delete)(GeoIPRecord *gir) = NULL;
 typedef void (*dl_GeoIPRecord_delete_t)(GeoIPRecord *gir);
 static union { dl_GeoIPRecord_delete_t func; void * obj; } dl_GeoIPRecord_delete;
 
 static int dl_status_GeoIP_country_code_by_addr_v6 = IPV6CALC_DL_STATUS_UNKNOWN;
-//static char* (*dl_GeoIP_country_code_by_addr_v6)(GeoIP* gi, const char *addr) = NULL;
 typedef char *(*dl_GeoIP_country_code_by_addr_v6_t)(GeoIP* gi, const char *addr);
 static union { dl_GeoIP_country_code_by_addr_v6_t func; void * obj; } dl_GeoIP_country_code_by_addr_v6;
 
 static int dl_status_GeoIP_country_name_by_addr_v6 = IPV6CALC_DL_STATUS_UNKNOWN;
-//static char* (*dl_GeoIP_country_name_by_addr_v6)(GeoIP* gi, const char *addr) = NULL;
 typedef char *(*dl_GeoIP_country_name_by_addr_v6_t)(GeoIP* gi, const char *addr);
 static union { dl_GeoIP_country_name_by_addr_v6_t func; void * obj; } dl_GeoIP_country_name_by_addr_v6;
 
 static int dl_status_GeoIP_name_by_addr_v6 = IPV6CALC_DL_STATUS_UNKNOWN;
-//static char* (*dl_GeoIP_name_by_addr_v6)(GeoIP* gi, const char *addr) = NULL;
 typedef char *(*dl_GeoIP_name_by_addr_v6_t)(GeoIP* gi, const char *addr);
 static union { dl_GeoIP_name_by_addr_v6_t func; void * obj; } dl_GeoIP_name_by_addr_v6;
 
 static int dl_status_GeoIP_lib_version = IPV6CALC_DL_STATUS_UNKNOWN;
-//static char* (*dl_GeoIP_lib_version)() = NULL;
 typedef char *(*dl_GeoIP_lib_version_t)(void);
 static union { dl_GeoIP_lib_version_t func; void * obj; } dl_GeoIP_lib_version;
 
 static int dl_status_GeoIP_cleanup = IPV6CALC_DL_STATUS_UNKNOWN;
-//static int (*dl_GeoIP_cleanup)() = NULL;
 typedef int (*dl_GeoIP_cleanup_t)(void);
 static union { dl_GeoIP_cleanup_t func; void * obj; } dl_GeoIP_cleanup;
 
 static int dl_status_GeoIP_setup_custom_directory = IPV6CALC_DL_STATUS_UNKNOWN;
-//static void (*dl_GeoIP_setup_custom_directory)(char *dir) = NULL;
 typedef void (*dl_GeoIP_setup_custom_director_t)(char *dir);
 static union { dl_GeoIP_setup_custom_director_t func; void * obj; } dl_GeoIP_setup_custom_directory;
 
-//static const char **dl_GeoIPDBDescription = NULL;
 typedef const char **(dl_GeoIPDBDescription_t);
 static union { dl_GeoIPDBDescription_t val; void * obj; } dl_GeoIPDBDescription;
 
@@ -149,12 +131,10 @@ typedef struct in6_addr geoipv6_t;
 #endif // SUPPORT_GEOIP_IPV6_STRUCT
 
 static int dl_status_GeoIP_country_name_by_ipnum_v6 = IPV6CALC_DL_STATUS_UNKNOWN;
-//static char* (*dl_GeoIP_country_name_by_ipnum_v6)(GeoIP* gi, geoipv6_t ipnum);
 typedef char *(*dl_GeoIP_country_name_by_ipnum_v6_t)(GeoIP* gi, geoipv6_t ipnum);
 static union { dl_GeoIP_country_name_by_ipnum_v6_t func; void * obj; } dl_GeoIP_country_name_by_ipnum_v6;
 
 static int dl_status_GeoIP_country_code_by_ipnum_v6 = IPV6CALC_DL_STATUS_UNKNOWN;
-//static char* (*dl_GeoIP_country_code_by_ipnum_v6)(GeoIP* gi, geoipv6_t ipnum) = NULL;
 typedef char *(*dl_GeoIP_country_code_by_ipnum_v6_t)(GeoIP* gi, geoipv6_t ipnum);
 static union { dl_GeoIP_country_code_by_ipnum_v6_t func; void * obj; } dl_GeoIP_country_code_by_ipnum_v6;
 
@@ -207,6 +187,8 @@ int libipv6calc_db_wrapper_GeoIP_wrapper_init(void) {
 
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Load library: %s", geoip_lib_file);
 
+	dlerror();    /* Clear any existing error */
+
 	dl_GeoIP_handle = dlopen(geoip_lib_file, RTLD_NOW | RTLD_LOCAL);
 
 	if (dl_GeoIP_handle == NULL) {
@@ -364,11 +346,13 @@ int libipv6calc_db_wrapper_GeoIP_wrapper_init(void) {
 	};
 
 #ifdef SUPPORT_GEOIP_V6
+#if HAVE_DECL_GEOIP_COUNTRY_EDITION_V6 == 1
 	if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_COUNTRY_EDITION_V6) == 1) {
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_COUNTRY_EDITION_V6 available");
 		geoip_country_v6 = 1;
 		wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP] |= IPV6CALC_DB_IPV6_TO_CC | IPV6CALC_DB_GEOIP_IPV6 | IPV6CALC_DB_IPV6_TO_COUNTRY;
 	};
+#endif
 #endif
 
 	if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_ASNUM_EDITION) == 1) {
@@ -516,11 +500,11 @@ void libipv6calc_db_wrapper_GeoIP_wrapper_print_db_info(const int level_verbose,
 
 #ifdef SUPPORT_GEOIP_DYN
 	if (dl_GeoIP_handle == NULL) {
-		printf("%sGeoIP: info of available databases in directory: %s LIBRARY-NOT-LOADED\n", prefix, geoip_db_dir);
+		fprintf(stderr, "%sGeoIP: info of available databases in directory: %s LIBRARY-NOT-LOADED\n", prefix, geoip_db_dir);
 	} else {
 #endif // SUPPORT_GEOIP_DYN
 
-	printf("%sGeoIP: info of available databases in directory: %s (max: %d)\n", prefix, geoip_db_dir, geoip_num_db_types - 1);
+	fprintf(stderr, "%sGeoIP: info of available databases in directory: %s (max: %d)\n", prefix, geoip_db_dir, geoip_num_db_types - 1);
 
 	for (i = 0; i < geoip_num_db_types; i++) {
 		if (libipv6calc_db_wrapper_GeoIP_db_avail(i)) {
@@ -540,11 +524,11 @@ void libipv6calc_db_wrapper_GeoIP_wrapper_print_db_info(const int level_verbose,
 #endif
 
 				if (level_verbose == LEVEL_VERBOSE2) {
-					printf("%sGeoIP: %-33s:[%2d] %-40s (CAN'T OPEN)\n", prefix, libipv6calc_db_wrapper_GeoIPDBDescription[i], i, (*libipv6calc_db_wrapper_GeoIPDBFileName_ptr)[i]);
+					fprintf(stderr, "%sGeoIP: %-33s:[%2d] %-20s (CAN'T OPEN)\n", prefix, libipv6calc_db_wrapper_GeoIPDBDescription[i], i, rindex((*libipv6calc_db_wrapper_GeoIPDBFileName_ptr)[i], '/') + 1);
 				};
 			} else {
 				count++;
-				printf("%sGeoIP: %-33s:[%2d] %-40s (%s)\n", prefix, libipv6calc_db_wrapper_GeoIPDBDescription[i], i, (*libipv6calc_db_wrapper_GeoIPDBFileName_ptr)[i], libipv6calc_db_wrapper_GeoIP_database_info(gi));
+				fprintf(stderr, "%sGeoIP: %-33s:[%2d] %-20s (%s)\n", prefix, libipv6calc_db_wrapper_GeoIPDBDescription[i], i, rindex((*libipv6calc_db_wrapper_GeoIPDBFileName_ptr)[i], '/') + 1, libipv6calc_db_wrapper_GeoIP_database_info(gi));
 			};
 		} else {
 			if (geoip_num_db_types > 0) {
@@ -553,7 +537,7 @@ void libipv6calc_db_wrapper_GeoIP_wrapper_print_db_info(const int level_verbose,
 				};
 
 				if (level_verbose == LEVEL_VERBOSE2) {
-					// printf("%sGeoIP: %-33s: %-40s (MISSING FILE)\n", prefix, libipv6calc_db_wrapper_GeoIPDBDescription[i], (*libipv6calc_db_wrapper_GeoIPDBFileName_ptr)[i]);
+					// fprintf(stderr, "%sGeoIP: %-33s: %-40s (MISSING FILE)\n", prefix, libipv6calc_db_wrapper_GeoIPDBDescription[i], (*libipv6calc_db_wrapper_GeoIPDBFileName_ptr)[i]);
 				} else {
 					continue;
 				};
@@ -561,18 +545,18 @@ void libipv6calc_db_wrapper_GeoIP_wrapper_print_db_info(const int level_verbose,
 		};
 	};
 	if ((geoip_num_db_types == 0) && (level_verbose == LEVEL_VERBOSE2)) {
-		printf("%sGeoIP: other possible databases can't be displayed, number of entries can't be retrieved (missing support)\n", prefix);
+		fprintf(stderr, "%sGeoIP: other possible databases can't be displayed, number of entries can't be retrieved (missing support)\n", prefix);
 	};
 #ifdef SUPPORT_GEOIP_DYN
 	};
 #endif
 
 	if (count == 0) {
-		printf("%sGeoIP: No available databases found in directory: %s\n", prefix, geoip_db_dir);
+		fprintf(stderr, "%sGeoIP: No available databases found in directory: %s\n", prefix, geoip_db_dir);
 	};
 
 #else
-	snprintf(string, size, "%sNo GeoIP support built-in", prefix);
+	snfprintf(stderr, string, size, "%sNo GeoIP support built-in", prefix);
 #endif
 
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Finished");
@@ -1957,8 +1941,10 @@ const char *libipv6calc_db_wrapper_GeoIP_wrapper_country_code_by_addr(const char
 	if (proto == 4) {
 		GeoIP_type = GEOIP_COUNTRY_EDITION;
 #ifdef SUPPORT_GEOIP_V6
+#if HAVE_DECL_GEOIP_COUNTRY_EDITION_V6 == 1
 	} else if (proto == 6) {
 		GeoIP_type = GEOIP_COUNTRY_EDITION_V6;
+#endif
 #endif // SUPPORT_GEOIP_V6
 	} else {
 		goto END_libipv6calc_db_wrapper;
@@ -2018,8 +2004,10 @@ const char *libipv6calc_db_wrapper_GeoIP_wrapper_country_name_by_addr(const char
 	if (proto == 4) {
 		GeoIP_type = GEOIP_COUNTRY_EDITION;
 #ifdef SUPPORT_GEOIP_V6
+#if HAVE_DECL_GEOIP_COUNTRY_EDITION_V6 == 1
 	} else if (proto == 6) {
 		GeoIP_type = GEOIP_COUNTRY_EDITION_V6;
+#endif
 #endif // SUPPORT_GEOIP_V6
 	} else {
 		return (NULL);
