@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calc/ipv6calc.c
- * Version    : $Id: ipv6calc.c,v 1.116 2014/09/13 21:15:08 ds6peter Exp $
- * Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6calc.c,v 1.127 2015/08/23 09:53:27 ds6peter Exp $
+ * Copyright  : 2001-2015 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Central program (main)
@@ -15,6 +15,8 @@
 #include <getopt.h> 
 #include <unistd.h>
 
+#include "config.h"
+
 #include "ipv6calc.h"
 #include "libipv6calc.h"
 #include "libipv6calcdebug.h"
@@ -39,8 +41,8 @@
 #include "librfc3056.h"
 #include "librfc3041.h"
 #include "librfc5569.h"
+#include "librfc6052.h"
 #include "libeui64.h"
-#include "config.h"
 #include "libieee.h"
 #include "libipv4addr.h"
 #include "libipv6addr.h"
@@ -78,10 +80,20 @@ int feature_zeroize = 1; // always supported
 int feature_anon    = 1; // always supported
 int feature_kp      = 0; // will be checked later
 
+/* showinfo machine readable filter */
+char showinfo_machine_readable_filter[32] = "";
+int showinfo_machine_readable_filter_used = 0;
+
 
 /**************************************************/
 /* main */
 int main(int argc, char *argv[]) {
+	/* check compatibility */
+#ifdef SHARED_LIBRARY
+	IPV6CALC_LIB_VERSION_CHECK_EXIT(IPV6CALC_PACKAGE_VERSION_NUMERIC, IPV6CALC_PACKAGE_VERSION_STRING)
+	IPV6CALC_DB_LIB_VERSION_CHECK_EXIT(IPV6CALC_PACKAGE_VERSION_NUMERIC, IPV6CALC_PACKAGE_VERSION_STRING)
+#endif // SHARED_LIBRARY
+
 	char resultstring[NI_MAXHOST] = "";
 	char resultstring2[NI_MAXHOST] = "";
 	char resultstring3[NI_MAXHOST] = "";
@@ -93,6 +105,8 @@ int main(int argc, char *argv[]) {
 	int inputc;
 	int inputtype_given = 0, outputtype_given = 0, action_given = 0;
 
+	int ipv6rd_prefixlength = -1;
+
 	/* new option style storage */	
 	uint32_t inputtype  = FORMAT_undefined;
 	uint32_t outputtype = FORMAT_undefined;
@@ -136,7 +150,7 @@ int main(int argc, char *argv[]) {
 	int flush_mode = 0;
 
 	/* options */
-	struct option longopts[MAXLONGOPTIONS];
+	struct option longopts[IPV6CALC_MAXLONGOPTIONS];
 	char   shortopts[NI_MAXHOST] = "";
 	int    longopts_maxentries = 0;
 
@@ -169,6 +183,9 @@ int main(int argc, char *argv[]) {
 			i++;
 		};
 	DEBUGSECTION_END
+
+	/* initialize options from environment */
+	ipv6calc_common_options_from_env(longopts, &ipv6calc_anon_set);
 	
 	while ((i = getopt_long(argc, argv, shortopts, longopts, &lop)) != EOF) {
 		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Parsing option: 0x%08x", i);
@@ -356,6 +373,16 @@ int main(int argc, char *argv[]) {
 				retval = addr_to_ipv6addrstruct(optarg, resultstring, sizeof(resultstring), &ipv6addr);
 				break;
 
+			case CMD_6rd_prefixlength:
+				DEBUGPRINT_NA(DEBUG_ipv6calc_general, "special option '6rd_prefixlength' selected");
+				if ((atoi(optarg) >= 1) && (atoi(optarg) <= 32)) {
+					ipv6rd_prefixlength = atoi(optarg);
+				} else {
+					fprintf(stderr, " Argument of option '6rd_prefixlength' is out or range (1-32): %d\n", atoi(optarg));
+					exit(EXIT_FAILURE);
+				};
+				break;
+
 			/* format options */
 			case 'C':
 			case FORMATOPTION_NUM_printcompressed + FORMATOPTION_NUM_HEAD:
@@ -430,7 +457,52 @@ int main(int argc, char *argv[]) {
 					exit(EXIT_FAILURE);
 				};
 				break;
+
+			case FORMATOPTION_NUM_mr_quote_always + FORMATOPTION_NUM_HEAD:
+				formatoptions |= (FORMATOPTION_mr_quote_always | FORMATOPTION_machinereadable);
+				break;
+
+			case FORMATOPTION_NUM_mr_quote_never + FORMATOPTION_NUM_HEAD:
+				formatoptions |= (FORMATOPTION_mr_quote_never | FORMATOPTION_machinereadable);
+				break;
+
+			case FORMATOPTION_NUM_mr_value_only + FORMATOPTION_NUM_HEAD:
+				if (strlen(showinfo_machine_readable_filter) >= sizeof(showinfo_machine_readable_filter)) {
+					fprintf(stderr, " Argument of option 'mrtvo' is too long: %s\n", optarg);
+					exit(EXIT_FAILURE);
+				};
+				snprintf(showinfo_machine_readable_filter, sizeof(showinfo_machine_readable_filter), "%s", optarg);
+				formatoptions |= (FORMATOPTION_mr_select_token | FORMATOPTION_mr_value_only | FORMATOPTION_machinereadable);
+				break;
 				
+			case FORMATOPTION_NUM_mr_select_token + FORMATOPTION_NUM_HEAD:
+				if (strlen(showinfo_machine_readable_filter) >= sizeof(showinfo_machine_readable_filter)) {
+					fprintf(stderr, " Argument of option 'mrst' is too long: %s\n", optarg);
+					exit(EXIT_FAILURE);
+				};
+				snprintf(showinfo_machine_readable_filter, sizeof(showinfo_machine_readable_filter), "%s", optarg);
+				formatoptions |= (FORMATOPTION_mr_select_token | FORMATOPTION_machinereadable);
+				break;
+
+			case FORMATOPTION_NUM_mr_select_token_pa + FORMATOPTION_NUM_HEAD:
+				if (strlen(showinfo_machine_readable_filter) >= sizeof(showinfo_machine_readable_filter)) {
+					fprintf(stderr, " Argument of option 'mrstpa' is too long: %s\n", optarg);
+					exit(EXIT_FAILURE);
+				};
+				snprintf(showinfo_machine_readable_filter, sizeof(showinfo_machine_readable_filter), "%s", optarg);
+				formatoptions |= (FORMATOPTION_mr_select_token | FORMATOPTION_mr_select_token_pa | FORMATOPTION_machinereadable);
+				break;
+
+			case FORMATOPTION_NUM_mr_match_token + FORMATOPTION_NUM_HEAD:
+				if (strlen(showinfo_machine_readable_filter) >= sizeof(showinfo_machine_readable_filter)) {
+					fprintf(stderr, " Argument of option 'mrmt' is too long: %s\n", optarg);
+					exit(EXIT_FAILURE);
+				};
+				snprintf(showinfo_machine_readable_filter, sizeof(showinfo_machine_readable_filter), "%s", optarg);
+				formatoptions |= (FORMATOPTION_mr_match_token | FORMATOPTION_machinereadable);
+				break;
+
+
 			case 'm':	
 			case FORMATOPTION_NUM_machinereadable + FORMATOPTION_NUM_HEAD:
 				formatoptions |= FORMATOPTION_machinereadable;
@@ -538,7 +610,7 @@ int main(int argc, char *argv[]) {
 	};
 
 	/* initialise database wrapper */
-	result = libipv6calc_db_wrapper_init();
+	result = libipv6calc_db_wrapper_init("");
 	if (result != 0) {
 		exit(EXIT_FAILURE);
 	};
@@ -612,6 +684,13 @@ int main(int argc, char *argv[]) {
 		};
 	};
 
+	if (action == ACTION_filter) {
+		if (libipv6calc_filter_check(&filter_master) != 0) {
+			fprintf(stderr, "ipv6calc filter check causes a problem\n");
+			exit(EXIT_FAILURE);
+		};
+	};
+
 	if (argc > 0) {
 		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Got input %s", argv[0]);
 	} else {
@@ -997,6 +1076,12 @@ PIPE_input:
 	};
 
 	if (ipv6addr.flag_valid == 1) {
+		/* honor 6rd prefix length option */
+		if (ipv6rd_prefixlength > 0) {
+			ipv6addr.typeinfo2 |= IPV6_ADDR_TYPE2_6RD;
+			ipv6addr.prefix2length = ipv6rd_prefixlength;
+		};
+
 		/* force prefix */
 		if ((formatoptions & (FORMATOPTION_forceprefix)) != 0) {
 			ipv6addr.flag_prefixuse = 1;
@@ -1111,8 +1196,10 @@ PIPE_input:
 			fprintf(stderr, "No output type specified, try autodetection...");
 		};
 
-		if ( (inputtype == FORMAT_ipv4addr) && (action == ACTION_ipv4_to_6to4addr) ) {
+		if ( (inputtype == FORMAT_ipv4addr) && ((action == ACTION_ipv4_to_6to4addr) || (action == ACTION_ipv4_to_nat64)) ) {
 			outputtype = FORMAT_ipv6addr;
+		} else if ( (inputtype == FORMAT_ipv6addr) && ((action == ACTION_ipv4_to_6to4addr) || (action == ACTION_ipv4_to_nat64)) ) {
+			outputtype = FORMAT_ipv4addr;
 		} else if ( (inputtype == FORMAT_mac) && (action == ACTION_mac_to_eui64) ) {
 			outputtype = FORMAT_eui64;
 			formatoptions |= FORMATOPTION_printfulluncompressed;
@@ -1130,6 +1217,8 @@ PIPE_input:
 			outputtype = FORMAT_ipv6addr;
 		} else if ( (inputtype == FORMAT_ipv4addr) && (action == ACTION_6rd_local_prefix) ) {
 			outputtype = FORMAT_ipv6addr;
+		} else if ( (inputtype == FORMAT_ipv6addr) && (action == ACTION_6rd_extract_ipv4) ) {
+			outputtype = FORMAT_ipv4addr;
 		};
 
 		if ( outputtype != FORMAT_undefined ) {
@@ -1190,6 +1279,27 @@ PIPE_input:
 			};
 			break;
 
+		case ACTION_ipv4_to_nat64:
+			if (inputtype == FORMAT_ipv4addr && outputtype == FORMAT_ipv6addr) {
+				/* IPv4 -> IPv6 */
+				if (ipv4addr.flag_valid != 1) {
+					fprintf(stderr, "No valid IPv4 address given!\n");
+					exit(EXIT_FAILURE);
+				};
+				retval = librfc6052_ipv4addr_to_ipv6addr(&ipv6addr, &ipv4addr);
+			} else if (inputtype == FORMAT_ipv6addr && outputtype == FORMAT_ipv4addr) {
+				/* IPv6 -> IPv4 */
+				if (ipv6addr.flag_valid != 1) {
+					fprintf(stderr, "No valid IPv6 address given!\n");
+					exit(EXIT_FAILURE);
+				};
+				retval = librfc6052_ipv6addr_to_ipv4addr(&ipv4addr, &ipv6addr, resultstring, sizeof(resultstring));
+			} else {
+				fprintf(stderr, "Unsupported NAT64 conversion!\n");
+				exit(EXIT_FAILURE);
+			};
+			break;
+
 		case ACTION_anonymize:
 			if ((inputtype == FORMAT_ipv4addr || inputtype == FORMAT_ipv4hex || inputtype == FORMAT_ipv4revhex) && outputtype == FORMAT_ipv4addr) {
 				/* anonymize IPv4 address */
@@ -1281,38 +1391,62 @@ PIPE_input:
 			if ( ipv6addr.flag_valid != 1 ) {
 				fprintf(stderr, "No valid IPv6 address given as 6rd prefix!\n");
 				exit(EXIT_FAILURE);
-			}
+			};
 
 			if ( !ipv6addr.flag_prefixuse ) {
 				fprintf(stderr, "Specified IPv6 address has no prefix length!\n");
 				exit(EXIT_FAILURE);
-			}
+			};
 
 			/* check IPv4 local ip */
 			if ( ipv4addr.flag_valid != 1 ) {
 				fprintf(stderr, "No valid IPv4 address given as local IP!\n");
 				exit(EXIT_FAILURE);
-			}
+			};
 		
 			if ( ipv4addr.flag_prefixuse ) {
 				fprintf(stderr, "No prefix length should be specified for the local IP!\n");
 				exit(EXIT_FAILURE);
-			}
+			};
 
 			/* check IPv4 relay prefix */
-			if ( ipv4addr2.flag_valid != 1 ) {
-				fprintf(stderr, "No valid IPv4 address given as 6rd relay prefix!\n");
-				exit(EXIT_FAILURE);
-			}
-
-			if ( !ipv4addr2.flag_prefixuse ) {
-				fprintf(stderr, "Specified relay prefix IPv4 address has no prefix length!\n");
-				exit(EXIT_FAILURE);
-			}
+			if ( ipv4addr2.flag_valid == 1 ) {
+				if ( !ipv4addr2.flag_prefixuse ) {
+					fprintf(stderr, "Specified relay prefix IPv4 address has no prefix length!\n");
+					exit(EXIT_FAILURE);
+				};
+			};
 
 			retval = librfc5569_calc_6rd_local_prefix(&ipv6addr, &ipv4addr2, &ipv4addr, resultstring, sizeof(resultstring));
 			break;
 
+		case ACTION_6rd_extract_ipv4:
+			/* check formats */
+			if ( outputtype != FORMAT_ipv4addr ) {
+				fprintf(stderr, "output type incompatible (no IPv4 address)!\n");
+				exit(EXIT_FAILURE);
+			};
+	
+			if ( inputtype != FORMAT_ipv6addr ) {
+				fprintf(stderr, "input type incompatible (no IPv6 address)!\n");
+				exit(EXIT_FAILURE);
+			};
+	
+			/* check IPv6 address */
+			if ( ipv6addr.flag_valid != 1 ) {
+				fprintf(stderr, "No valid IPv6 address given!\n");
+				exit(EXIT_FAILURE);
+			};
+
+			/* check IPv4 relay prefix */
+			if (ipv6rd_prefixlength < 1) {
+				fprintf(stderr, "No IPv6 Rapid Deployment prefix length given!\n");
+				exit(EXIT_FAILURE);
+			};
+
+			retval = libipv6addr_get_included_ipv4addr(&ipv6addr, &ipv4addr, IPV6_ADDR_SELECT_IPV4_PREFIX2_LENGTH);
+			break;
+
 		case ACTION_filter:
 			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of action: filter");
 
@@ -1329,13 +1463,12 @@ PIPE_input:
 				/* call filter for MAC addresses */
 				result = macaddr_filter(&macaddr, &filter_master.filter_macaddr);
 			} else {
-				/* TODO: more specific notice */
-				fprintf(stderr, "Action-type isn't currently implemented for inputtype\n");
+				NONQUIETPRINT_WA("Action-type 'filter' isn't currently implemented for inputtype: %s", ipv6calctypes_format_string_by_type(inputtype));
 			};
 
-			if (result != 0) {
+			if (result > 0) {
 				/* skip everything */
-				DEBUGPRINT_WA(DEBUG_ipv6calc_general, "filter result SKIP: '%s'", linebuffer);
+				DEBUGPRINT_WA(DEBUG_ipv6calc_general, "filter result SKIP (%d): '%s'", result, linebuffer);
 			} else {
 				snprintf(resultstring, sizeof(resultstring), "%s", linebuffer);
 			};
