@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc/ipv6calc
  * File       : ipv6calc/ipv6calcoptions.h
- * Version    : $Id: ipv6calcoptions_local.h,v 1.6 2014/07/21 06:14:27 ds6peter Exp $
- * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6calcoptions_local.h,v 1.10 2015/05/27 06:17:50 ds6peter Exp $
+ * Copyright  : 2002-2015 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file containing options for ipv6calc
@@ -76,6 +76,7 @@ static struct option ipv6calc_longopts[] = {
 	
 	{ "showinfo"                , 0, NULL, CMD_showinfo },
 	{ "show_types"              , 0, NULL, CMD_showinfotypes },
+	{ "show-tokens"             , 0, NULL, CMD_showinfotypes },
 
 	/* format options */
 	{ "maskprefix"           , 0, NULL, FORMATOPTION_NUM_maskprefix + FORMATOPTION_NUM_HEAD },
@@ -97,6 +98,13 @@ static struct option ipv6calc_longopts[] = {
 	
 	{ "machine_readable"     , 0, NULL, FORMATOPTION_NUM_machinereadable + FORMATOPTION_NUM_HEAD },
 	// { "quiet"                , 0, NULL, FORMATOPTION_NUM_quiet + FORMATOPTION_NUM_HEAD }, strange duplicate
+	/* machine readable format/filter */
+	{ "mrqva"                , 0, NULL, FORMATOPTION_NUM_mr_quote_always + FORMATOPTION_NUM_HEAD },
+	{ "mrqvn"                , 0, NULL, FORMATOPTION_NUM_mr_quote_never  + FORMATOPTION_NUM_HEAD },
+	{ "mrtvo"                , 1, NULL, FORMATOPTION_NUM_mr_value_only   + FORMATOPTION_NUM_HEAD },
+	{ "mrst"                 , 1, NULL, FORMATOPTION_NUM_mr_select_token + FORMATOPTION_NUM_HEAD },
+	{ "mrstpa"               , 1, NULL, FORMATOPTION_NUM_mr_select_token_pa + FORMATOPTION_NUM_HEAD },
+	{ "mrmt"                 , 1, NULL, FORMATOPTION_NUM_mr_match_token  + FORMATOPTION_NUM_HEAD },
 	
 	{ "printmirrored"        , 0, NULL, FORMATOPTION_NUM_printmirrored + FORMATOPTION_NUM_HEAD },
 
@@ -107,9 +115,12 @@ static struct option ipv6calc_longopts[] = {
 	{ "out"       , 1, NULL, CMD_outputtype },
 	{ "action"    , 1, NULL, CMD_actiontype },
 
-	/* 6rd_prefix options */
+	/* 6rd_prefix options for action */
 	{ "6rd_relay_prefix"	, 1, NULL, CMD_6rd_relay_prefix },
 	{ "6rd_prefix"		, 1, NULL, CMD_6rd_prefix },
+
+	/* 6rd_prefix options for showinfo/action */
+	{ "6rd_prefixlength"	, 1, NULL, CMD_6rd_prefixlength },
 }; 
 
 
