@@ -2,52 +2,31 @@
 #
 # Project    : ipv6calc
 # File       : test_ipv6calc.sh
-# Version    : $Id: test_ipv6calc.sh,v 1.51 2014/08/27 04:44:23 ds6peter Exp $
-# Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: test_ipv6calc.sh,v 1.57 2015/08/23 09:53:27 ds6peter Exp $
+# Copyright  : 2001-2015 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test patterns for ipv6calc conversions
 
+verbose=0
+while getopts "Vh\?" opt; do
+	case $opt in
+	    V)
+		verbose=1
+		;;
+	    *)
+		echo "$0 [-V]"
+		echo "    -V   verbose"
+		exit 1
+		;;
+	esac
+done
+	
+
 if [ ! -x ./ipv6calc ]; then
 	echo "Binary './ipv6calc' missing or not executable"
 	exit 1
 fi
 
-# Test proper option definitions
-echo "Test proper option definition"
-./ipv6calc -h >/dev/null
-if [ $? -ne 1 ]; then
-	echo "ERROR : something wrong in option definition"
-	exit 1
-fi
-
-## version
-echo "Run 'ipv6calc' version test..."
-./ipv6calc -vvv
-retval=$?
-if [ $retval -ne 0 ]; then
-	echo "Error executing 'ipv6calc -vvv'!"
-	exit 1
-fi
-echo 
-
-echo "Run 'ipv6calc' version test in debug mode..."
-./ipv6calc -vvv -d -1
-retval=$?
-if [ $retval -ne 0 ]; then
-	echo "Error executing 'ipv6calc -vvv -d -1'!"
-	exit 1
-fi
-echo 
-
-echo "Run 'ipv6calc' version help test for feature tokens..."
-./ipv6calc -v -h
-retval=$?
-if [ $retval -ne 0 ]; then
-	echo "Error executing 'ipv6calc -v -h'!"
-	exit 1
-fi
-echo 
-
 
 # Test Scenarios for autodetection "good case"
 source ./test_scenarios.sh
@@ -58,7 +37,7 @@ cat <<END | grep -v '^#'
 ## Machine readable format
 -m -F ::1								=IPV6=0000:0000:0000:0000:0000:0000:0000:0001
 -m ::1									=IPV6=::1
--m 1.2.3.4								=IPV4=1.2.3.4
+-m 2.2.3.4								=IPV4=2.2.3.4
 ## ip6.int.
 --addr_to_ip6int 3ffe:ffff:100:f101::1					=1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.1.0.1.f.0.0.1.0.f.f.f.f.e.f.f.3.ip6.int.
 --in ipv6 --out revnibbles.int 3ffe:ffff:100:f101::1			=1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.1.0.1.f.0.0.1.0.f.f.f.f.e.f.f.3.ip6.int.
@@ -78,7 +57,7 @@ cat <<END | grep -v '^#'
 --in ipv6 --out ipv6 --printcompressed 3ffe:ffff:0100:f101:0000:0000:0000:0001 =3ffe:ffff:100:f101::1
 -I ipv6 -O ipv6 -C 3ffe:ffff:0100:f101:0000:0000:0000:0001 		=3ffe:ffff:100:f101::1
 --addr_to_compressed 3ffe:ffff:0100:f101:0000:0000:0000:0001/64		=3ffe:ffff:100:f101::1/64
---addr_to_compressed 0:0:1:2:3:4:0:0					=::1:2:3:4:0:0
+--addr_to_compressed 0:0:2:2:3:4:0:0					=::2:2:3:4:0:0
 --addr_to_compressed 0:0:1:0:0:1:0:0					=::1:0:0:1:0:0
 --addr_to_compressed 0:0:0:2:3:0:0:0					=::2:3:0:0:0
 --addr_to_compressed 0:0:0:0:3:0:0:0					=::3:0:0:0
@@ -164,8 +143,14 @@ NOPIPETEST--out eui64 00:0:F:6:4:5					=200:fff:fe06:405
 ## IPv4 -> IPv6 (6to4)
 --ipv4_to_6to4addr 11.12.13.14						=2002:b0c:d0e::
 --in ipv4 --out ipv6 --action conv6to4 11.12.13.14			=2002:b0c:d0e::
+--action conv6to4 192.0.2.1						=2002:c000:201::
 ## IPv6 -> IPv4 (6to4)
 --in ipv6 --out ipv4 --action conv6to4 2002:102:304::1			=1.2.3.4
+--action conv6to4 2002:c000:201::					=192.0.2.1
+## IPv4 -> IPv6 (NAT64)
+--action convnat64 192.0.2.1						=64:ff9b::c000:201
+## IPv6 -> IPv4 (NAT64)
+--action convnat64 64:ff9b::c000:201					=192.0.2.1
 ## Prefix + MAC -> IPv6
 --in prefix+mac fec0:0:0:1:: 01:23:45:67:89:01				=fec0::1:323:45ff:fe67:8901
 ## IPv4 -> reverse
@@ -210,6 +195,12 @@ NOPIPETEST--out eui64 00:0:F:6:4:5					=200:fff:fe06:405
 --in ipv6addr --out ipv6addr 2001:DB8:0:0:1:0:0:1		 	=2001:db8::1:0:0:1
 # 6rd
 --action 6rd_local_prefix --6rd_prefix 2607:fedc:ff40::/43 --6rd_relay_prefix 6.230.0.0/15 6.231.32.33	=2607:fedc:ff52:210::/60
+--action 6rd_local_prefix --6rd_prefix 2001:0b4f::/28 192.0.2.1		=2001:b4c:0:2010::/60
+--action 6rd_local_prefix --6rd_prefix 2001:0b4f::/29 192.0.2.1		=2001:b4e:0:1008::/61
+--action 6rd_local_prefix --6rd_prefix 2001:0b4f::/30 192.0.2.1		=2001:b4f:0:804::/62
+--action 6rd_local_prefix --6rd_prefix 2001:0b4f::/31 192.0.2.1		=2001:b4f:8000:402::/63
+--action 6rd_local_prefix --6rd_prefix 2001:0b4f::/32 192.0.2.1		=2001:b4f:c000:201::/64
+-A 6rd_extract_ipv4 --6rd_prefixlength 28 2001:b4c:0:2010::/60		=192.0.2.1
 # IPv6 literal
 --in ipv6literal fe80--1.IPV6-LITERAL.NET				=fe80::1
 --in ipv6literal fe80--1.IPV6-liTERal.NET				=fe80::1
@@ -244,8 +235,8 @@ END
 testscenarios_auto_bad() {
 cat <<END | grep -v '^#'
 1.2.3.r4									ipv4addr
-1.2.3.4/-1									ipv4addr
-1.2.3.4/33									ipv4addr
+2.2.3.4/-1									ipv4addr
+2.2.3.4/33									ipv4addr
 01:23:r5:67:89:01								mac
 2002:102:304::r1								ipv6addr
 2002:102:304::1/-1								ipv6addr
@@ -267,29 +258,97 @@ END
 
 }
 
-#set -x
 ## main ##
-echo "Run 'ipv6calc' basic tests..."
 
-echo "Test './ipv6calc -v'"
-output="`./ipv6calc -v`"
+# Test proper option definitions
+test="test proper option definition"
+echo "INFO  : $test"
+if [ "$verbose" = "1" ]; then
+	./ipv6calc -h
+	retval=$?
+else
+	./ipv6calc -h 2>/dev/null
+	retval=$?
+fi
+if [ $retval -ne 1 ]; then
+	echo "ERROR : something wrong in option definition"
+	exit 1
+fi
+echo "INFO  : $test successful"
+
+
+test="run 'ipv6calc' version test"
+echo "INFO  : $test"
+if [ "$verbose" = "1" ]; then
+	./ipv6calc -vvv
+	retval=$?
+else
+	./ipv6calc -vvv 2>/dev/null
+	retval=$?
+fi
+if [ $retval -ne 0 ]; then
+	echo "Error executing 'ipv6calc -vvv'!"
+	exit 1
+fi
+echo "INFO  : $test successful"
+
+
+test="run 'ipv6calc' version test in debug mode"
+echo "INFO  : $test"
+if [ "$verbose" = "1" ]; then
+	./ipv6calc -vvv -d -1
+	retval=$?
+else
+	./ipv6calc -vvv -d -1 >/dev/null 2>&1
+	retval=$?
+fi
+if [ $retval -ne 0 ]; then
+	echo "Error executing 'ipv6calc -vvv -d -1'!"
+	exit 1
+fi
+echo "INFO  : $test successful"
+
+
+test="run 'ipv6calc' version help test for feature tokens"
+echo "INFO  : $test"
+if [ "$verbose" = "1" ]; then
+	./ipv6calc -v -h
+	retval=$?
+else
+	./ipv6calc -v -h 2>/dev/null
+	retval=$?
+fi
+if [ $retval -ne 0 ]; then
+	echo "Error executing 'ipv6calc -v -h'!"
+	exit 1
+fi
+echo "INFO  : $test successful"
+
+
+test="test './ipv6calc -v'"
+echo "INFO  : $test"
+output="`./ipv6calc -v 2>&1`"
 retval=$?
 if [ $retval -ne 0 ]; then
 	echo "Error executing: ipv6calc -v: $output"
 	exit 1
 fi
+echo "INFO  : $test successful"
 
-echo "Test './ipv6calc -v -v'"
-output="`./ipv6calc -v -v`"
+
+test="test './ipv6calc -v -v'"
+echo "INFO  : $test"
+output="`./ipv6calc -v -v 2>&1`"
 retval=$?
 if [ $retval -ne 0 ]; then
 	echo "Error executing: ipv6calc -v -v: $output"
 	exit 1
 fi
+echo "INFO  : $test successful"
 
 
-echo "Run 'ipv6calc' function tests..."
-
+test="run 'ipv6calc' function tests"
+echo "INFO  : $test"
 testscenarios | sed 's/NOPIPETEST//' | while read line; do
 	if [ -z "$line" ]; then
 		# end
@@ -303,81 +362,134 @@ testscenarios | sed 's/NOPIPETEST//' | while read line; do
 		echo "Something is wrong in line '$line'"
 		exit 1
 	fi
-	echo "Test './ipv6calc $command' for '$result'"
+
+	info="INFO  : test './ipv6calc $command' for '$result'"
+	[ "$verbose" = "1" ] && echo "$info"
+
 	#continue
 	# get result
-	output="`./ipv6calc $command`"
+	output="`./ipv6calc -q $command`"
 	retval=$?
 	if [ $retval -ne 0 ]; then
-		echo "Error executing 'ipv6calc'!"
+		[ "$verbose" = "1" ] || echo "$info"
+		echo "ERROR: problem executing: ./ipv6calc $command"
 		exit 1
 	fi
 	# Check result
 	if [ "$result" != "*" ]; then
 		if [ "$output" != "$result" ]; then
-			echo "Result '$output' doesn't match: $result"
+			[ "$verbose" = "1" ] || echo "$info"
+			echo "ERROR: result '$output' doesn't match: $result"
 			exit 1
 		fi
 	fi
-done || exit 1 
+	[ "$verbose" = "1" ] || echo -n "."
+done || exit 1
+[ "$verbose" = "1" ] || echo
+echo "INFO  : $test successful"
 
 
-echo "Run 'ipv6calc' action 'genprivacyiid'..."
+test="run 'ipv6calc' action 'genprivacyiid'"
+echo "INFO  : $test"
 testscenarios_genprivacyiid | while read in1 in2 out1 out2; do
-	echo "Test './ipv6calc -q -A genprivacyiid $in1 $in2'"
-	result="`./ipv6calc -A genprivacyiid $in1 $in2`"
+	info="INFO  : test './ipv6calc -q -A genprivacyiid $in1 $in2'"
+	[ "$verbose" = "1" ] && echo "$info"
+
+	result="`./ipv6calc -q -A genprivacyiid $in1 $in2`"
 	retval=$?
 
 	if [ $retval -ne 0 ]; then
+		[ "$verbose" = "1" ] || echo "$info"
 		echo "Error executing 'ipv6calc'!"
 		exit 1
 	fi
 
 	if [ "$result" != "$out1 $out2" ]; then
+		[ "$verbose" = "1" ] || echo "$info"
 		echo "Result is not matching!"
 		echo "Result is      : $result"
 		echo "Result expected: $out1 $out2"
 		exit 1
 	fi
+	[ "$verbose" = "1" ] || echo -n "."
 done || exit 1
+[ "$verbose" = "1" ] || echo
+echo "INFO  : $test successful"
 
 
-echo "Run 'ipv6calc' input validation tests...(empty input)"
+test="run 'ipv6calc' input validation tests (empty input)"
+echo "INFO  : $test"
 ./ipv6calc -m --in -? | while read inputformat; do
 	if echo $inputformat | grep -q '+'; then
-		echo "Test './ipv6calc -q --in $inputformat \"\" \"\"'"
-		./ipv6calc -q --in $inputformat "" ""
-		retval=$?
+		info="INFO  : test './ipv6calc -q --in $inputformat \"\" \"\"'"
+		[ "$verbose" = "1" ] && echo "$info"
+		if [ "$verbose" = "1" ]; then
+			./ipv6calc -q --in $inputformat "" ""
+			retval=$?
+		else
+			./ipv6calc -q --in $inputformat "" "" 2>/dev/null
+			retval=$?
+		fi
 	else
-		echo "Test './ipv6calc -q --in $inputformat \"\"'"
-		./ipv6calc -q --in $inputformat ""
-		retval=$?
+		info="INFO  : test './ipv6calc -q --in $inputformat \"\"'"
+		[ "$verbose" = "1" ] && echo "$info"
+		if [ "$verbose" = "1" ]; then
+			./ipv6calc -q --in $inputformat ""
+			retval=$?
+		else
+			./ipv6calc -q --in $inputformat "" 2>/dev/null
+			retval=$?
+		fi
 	fi
 	if [ $retval -ne 1 ]; then
+		[ "$verbose" = "1" ] || echo "$info"
 		echo "Error executing 'ipv6calc'!"
 		exit 1
 	fi
+	[ "$verbose" = "1" ] || echo -n "."
 done || exit 1
+[ "$verbose" = "1" ] || echo
+echo "INFO  : $test successful"
 
-echo "Run 'ipv6calc' input validation tests...(too long input)"
+
+test="run 'ipv6calc' input validation tests (too long input)"
+echo "INFO  : $test"
 line="`perl -e 'print "x" x300'`"
 ./ipv6calc -m --in -? | while read inputformat; do
 	if echo $inputformat | grep -q '+'; then
-		echo "Test './ipv6calc -q --in $inputformat \"$line\" \"$line\"'"
-		./ipv6calc -q --in $inputformat "$line" "$line"
-		retval=$?
+		info="INFO  : test './ipv6calc -q --in $inputformat \"$line\" \"$line\"'"
+		[ "$verbose" = "1" ] && echo "$info"
+		if [ "$verbose" = "1" ]; then
+			./ipv6calc -q --in $inputformat "$line" "$line"
+			retval=$?
+		else
+			./ipv6calc -q --in $inputformat "$line" "$line" 2>/dev/null
+			retval=$?
+		fi
 	else
-		echo "Test './ipv6calc -q --in $inputformat \"$line\"'"
-		./ipv6calc -q --in $inputformat "$line"
-		retval=$?
+		info="INFO  : test './ipv6calc -q --in $inputformat \"$line\"'"
+		[ "$verbose" = "1" ] && echo "$info"
+		if [ "$verbose" = "1" ]; then
+			./ipv6calc -q --in $inputformat "$line"
+			retval=$?
+		else
+			./ipv6calc -q --in $inputformat "$line" 2>/dev/null
+			retval=$?
+		fi
 	fi
 	if [ $retval -ne 1 ]; then
+		[ "$verbose" = "1" ] || echo "$info"
 		echo "Error executing 'ipv6calc'!"
 		exit 1
 	fi
+	[ "$verbose" = "1" ] || echo -n "."
 done || exit 1
+[ "$verbose" = "1" ] || echo
+echo "INFO  : $test successful"
 
-echo "Run 'ipv6calc' input validation tests...(strange input)"
+
+test="run 'ipv6calc' input validation tests (strange input)"
+echo "INFO  : $test"
 ./ipv6calc -m --in -? | while read inputformat; do
 	case $inputformat in
 	    hex|ifinet6)
@@ -388,69 +500,118 @@ echo "Run 'ipv6calc' input validation tests...(strange input)"
 		;;
 	esac
 	if echo $inputformat | grep -q '+'; then
-		echo "Test './ipv6calc -q --in $inputformat \"$line\" \"$line\"'"
-		./ipv6calc -q --in $inputformat "$line" "$line"
-		retval=$?
+		info="INFO  : test './ipv6calc -q --in $inputformat \"$line\" \"$line\"'"
+		[ "$verbose" = "1" ] && echo "$info"
+		if [ "$verbose" = "1" ]; then
+			./ipv6calc -q --in $inputformat "$line" "$line"
+			retval=$?
+		else
+			./ipv6calc -q --in $inputformat "$line" "$line" 2>/dev/null
+			retval=$?
+		fi
 	else
-		echo "Test './ipv6calc -q --in $inputformat \"$line\"'"
-		./ipv6calc -q --in $inputformat "$line"
-		retval=$?
+		info="INFO  : test './ipv6calc -q --in $inputformat \"$line\"'"
+		[ "$verbose" = "1" ] && echo "$info"
+		if [ "$verbose" = "1" ]; then
+			./ipv6calc -q --in $inputformat "$line"
+			retval=$?
+		else
+			./ipv6calc -q --in $inputformat "$line" 2>/dev/null
+			retval=$?
+		fi
 	fi
 	if [ $retval -ne 1 ]; then
+		[ "$verbose" = "1" ] || echo "$info"
 		echo "Error executing 'ipv6calc'!"
 		exit 1
 	fi
+	[ "$verbose" = "1" ] || echo -n "."
 done || exit 1
+[ "$verbose" = "1" ] || echo
+echo "INFO  : $test successful"
 
-echo "Run 'ipv6calc' input autodetection tests...(good cases)"
+
+test="run 'ipv6calc' input autodetection tests (good cases)"
+echo "INFO  : $test"
 testscenarios_auto_good | while read input dummy; do
-	echo "Test './ipv6calc -q \"$input\"'"
+	info="INFO  : test './ipv6calc -q \"$input\"'"
+	[ "$verbose" = "1" ] && echo "$info"
 	./ipv6calc -q "$input" >/dev/null
 	retval=$?
 	if [ $retval -ne 0 ]; then
+		[ "$verbose" = "1" ] || echo "$info"
 		echo "Error executing 'ipv6calc'!"
 		exit 1
 	fi
+	[ "$verbose" = "1" ] || echo -n "."
 done || exit 1
+[ "$verbose" = "1" ] || echo
+echo "INFO  : $test successful"
 
-echo "Run 'ipv6calc' input autodetection tests...(bad cases)"
+
+test="run 'ipv6calc' input autodetection tests (bad cases)"
+echo "INFO  : $test"
 testscenarios_auto_bad | while read input dummy; do
-	echo "Test './ipv6calc -q \"$input\"'"
-	./ipv6calc -q "$input" >/dev/null
-	retval=$?
+	info="INFO  : test './ipv6calc -q \"$input\"'"
+	[ "$verbose" = "1" ] && echo "$info"
+	if [ "$verbose" = "1" ]; then
+		./ipv6calc -q "$input"
+		retval=$?
+	else
+		./ipv6calc -q "$input" >/dev/null 2>&1
+		retval=$?
+	fi
 	if [ $retval -eq 0 ]; then
+		[ "$verbose" = "1" ] || echo "$info"
 		echo "Error executing 'ipv6calc' ($retval)!"
 		exit 1
 	fi
+	[ "$verbose" = "1" ] || echo -n "."
 done || exit 1
+[ "$verbose" = "1" ] || echo
+echo "INFO  : $test successful"
 
-echo "Run 'ipv6calc' input tests...(good cases)"
+test="run 'ipv6calc' input tests (good cases)"
+echo "INFO  : $test"
 testscenarios_auto_good | while read input type; do
-	echo "Test './ipv6calc --in $type -q \"$input\"'"
+	info="INFO  : test './ipv6calc --in $type -q \"$input\"'"
+	[ "$verbose" = "1" ] && echo "$info"
 	./ipv6calc --in $type -q "$input" >/dev/null
 	retval=$?
 	if [ $retval -ne 0 ]; then
+		[ "$verbose" = "1" ] || echo "$info"
 		echo "Error executing 'ipv6calc'!"
 		exit 1
 	fi
+	[ "$verbose" = "1" ] || echo -n "."
 done || exit 1
+[ "$verbose" = "1" ] || echo
+echo "INFO  : $test successful"
 
-echo "Run 'ipv6calc' pipe tests (1)"
+
+test="run 'ipv6calc' pipe tests (1)"
+echo "INFO  : $test"
 testscenarios_pipe | while IFS="," read input arguments result; do
-	echo "Test 'echo $input | ./ipv6calc $arguments | grep \"^$result\$\"'"
-	#set -x
-	echo -e $input | ./ipv6calc $arguments | grep "^$result\$" >/dev/null
+	info="INFO  : test 'echo $input | ./ipv6calc $arguments | grep \"^$result\$\"'"
+	[ "$verbose" = "1" ] && echo "$info"
+	output=$(echo -e $input | ./ipv6calc $arguments | grep "^$result\$")
 	retval=$?
-	#set +x
+	[ "$verbose" = "1" ] && echo "$output"
 	if [ $retval -ne 0 ]; then
+		[ "$verbose" = "1" ] || echo "$info"
 		echo "Error executing 'ipv6calc' ($retval)!"
 		exit 1
 	fi
+	[ "$verbose" = "1" ] || echo -n "."
 done || exit 1
+[ "$verbose" = "1" ] || echo
+echo "INFO  : $test successful"
 
-echo "Run 'ipv6calc' pipe tests (2)"
-# reuse original test cases
+
+test="run 'ipv6calc' pipe tests (2)"
+echo "INFO  : $test"
 testscenarios | grep -v "^NOPIPETEST" | while read line; do
+	# reuse original test cases
 	# extract result
 	command="`echo "$line" | awk -F= '{ print $1 }' | sed 's/ $//g'`"
 	result="`echo "$line" | awk -F= '{ for (i=2; i <= NF; i++) printf "%s%s", $i, (i<NF) ? "=" : ""; }'`"
@@ -469,47 +630,61 @@ testscenarios | grep -v "^NOPIPETEST" | while read line; do
 		options="`echo "$command" | awk '{ for (i=1; i < NF-1; i++) printf "%s ", $i; }'`"
 		;;
 	esac
-	echo "Test 'echo $stdin | ./ipv6calc $options | grep \"^$result\$\"'"
-	#set -x
+	info="INFO  : test 'echo $stdin | ./ipv6calc $options | grep \"^$result\$\"'"
+	[ "$verbose" = "1" ] && echo "$info"
 	output="`echo -e $stdin | ./ipv6calc $options`"
 	retval=$?
-	#set +x
 	if [ $retval -ne 0 ]; then
+		[ "$verbose" = "1" ] || echo "$info"
 		echo "Error executing 'ipv6calc' ($retval)!"
 		exit 1
 	fi
 	# Check result
 	if [ "$result" != "*" ]; then
 		if [ "$output" != "$result" ]; then
+			[ "$verbose" = "1" ] || echo "$info"
 			echo "Result '$output' doesn't match!"
 			exit 1
 		fi
 	fi
+	[ "$verbose" = "1" ] || echo -n "."
 done || exit 1
+[ "$verbose" = "1" ] || echo
+echo "INFO  : $test successful"
 
-echo "Run 'ipv6calc' pipe mode input validation tests...(too long input)"
+
+test="run 'ipv6calc' pipe mode input validation tests (too long input)"
+echo "INFO  : $test"
 ./ipv6calc -m --in -? | while read inputformat; do
 	if echo $inputformat | grep -q '+'; then
-		echo "Test '8192*x 8192*x | ./ipv6calc -q --in $inputformat"
-		perl -e 'print "x" x8192 . " " . "y" x8192' | ./ipv6calc -q --in $inputformat
+		info="INFO  : test '8192*x 8192*x | ./ipv6calc -q --in $inputformat"
+		[ "$verbose" = "1" ] && echo "$info"
+		output=$(perl -e 'print "x" x8192 . " " . "y" x8192' | ./ipv6calc -q --in $inputformat 2>&1)
 		retval=$?
 	else
-		echo "Test '8192*x | ./ipv6calc -q --in $inputformat"
-		perl -e 'print "x" x8192' | ./ipv6calc -q --in $inputformat
+		info="INFO  : test '8192*x | ./ipv6calc -q --in $inputformat"
+		[ "$verbose" = "1" ] && echo "$info"
+		output=$(perl -e 'print "x" x8192' | ./ipv6calc -q --in $inputformat 2>&1)
 		retval=$?
 	fi
+	[ "$verbose" = "1" ] && echo "$output"
 	if [ $retval -ne 0 -a $retval -ne 1 ]; then
+		[ "$verbose" = "1" ] || echo "$info"
 		echo "Error executing 'ipv6calc'!"
 		exit 1
 	fi
+	[ "$verbose" = "1" ] || echo -n "."
 done || exit 1
+[ "$verbose" = "1" ] || echo
+echo "INFO  : $test successful"
+
 
 retval=$?
 if [ $retval -eq 0 ]; then
-	echo "All tests were successfully done!"
+	echo "INFO  : all tests were successfully done!"
 	exit 0
 else
-	echo "Tests failed! (code $retval)"
+	echo "ERROR : tests failed! (code $retval)"
 	exit $retval
 fi
 
