@@ -2,11 +2,25 @@
 #
 # Project    : ipv6calc
 # File       : test_ipv6loganon.sh
-# Version    : $Id: test_ipv6loganon.sh,v 1.26 2014/07/29 20:01:55 ds6peter Exp $
-# Copyright  : 2007-2013 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: test_ipv6loganon.sh,v 1.29 2015/07/12 09:28:22 ds6peter Exp $
+# Copyright  : 2007-2015 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test program for "ipv6loganon"
 
+verbose=0
+while getopts "Vh\?" opt; do
+	case $opt in
+	    V)
+		verbose=1
+		;;
+	    *)
+		echo "$0 [-V]"
+		echo "    -V   verbose"
+		exit 1
+		;;
+	esac
+done
+
 if [ ! -x ./ipv6loganon ]; then
 	echo "Binary './ipv6loganon' missing or not executable"
 	exit 1
@@ -39,10 +53,10 @@ cat <<END | grep -v "^#"
 3ffe:ffff::1 - - IPv6 address/6bone/static IID	=3ffe:ffff::9:a929:4291:c02d:5d15 - - IPv6 address/6bone/static IID
 3FFE:1a05:510:200:0:5EFE:8CAD:8108 - - ISATAP	=3ffe:1a05:510:209:a929:5214:48ca:d81d - - ISATAP
 ff02::1:ff00:1234 - - Solicited Node		=ff02::1:ff00:0 - - Solicited Node
-3ffe::1:ff00:1234 - - Solicited Node		=3ffe::1:ff00:0 - - Solicited Node
+3ffe::1:ff00:1234 - - Solicited Node		=3ffe::9:0:1:ff00:0 - - Solicited Node
 ::1 - - loopback				=::1 - - loopback
-::1.2.3.4 - - compatible IPv4			=::1.2.3.0 - - compatible IPv4
-::ffff:1.2.3.4 - - mapped IPv4			=::ffff:1.2.3.0 - - mapped IPv4
+::2.2.3.4 - - compatible IPv4			=::2.2.3.0 - - compatible IPv4
+::ffff:2.2.3.4 - - mapped IPv4			=::ffff:2.2.3.0 - - mapped IPv4
 2002:0102:0204::1 - - 6to4 local		=2002:102:200:9:a929:4291:c02d:5d15 - - 6to4 local
 2002:50b5:7940::50b5:7940 - - 6to4 Microsoft	=2002:50b5:7900:9:a929:4291:850b:5794 - - 6to4 Microsoft
 fe80::210:a4ff:fe01:2345 - - link local EUI-48	=fe80::a909:4291:4021:a4c - - link local EUI-48
@@ -74,15 +88,14 @@ cat <<END_CACHE | grep -v "^#"
 195.226.187.50	- - "IPv4 address"
 3ffe:ffff::1	- - "IPv6 address/6bone test"
 3FFE:1a05:510:200:0:5EFE:8CAD:8108 - - 
-1.2.3.4 - -
-1.2.3.4 - -
+2.2.3.4 - -
+2.2.3.4 - -
 195.226.187.50	- - "IPv4 address"
-::ffff:1.2.3.4 - -
+::ffff:2.2.3.4 - -
 2002:0102:0204::1 - -
 fe80::210:a4ff:fe01:2345 - -
 fe80::210:a489:ab01:2345 - -
 3ffe:ffff::210:a4ff:fe01:2345 - -
-1.2.3.4 - -
 2.2.3.4 - -
 3.2.3.4 - -
 4.2.3.4 - -
@@ -127,6 +140,8 @@ END
 echo "Run 'ipv6loganon' function tests..." >&2
 
 if [ "$1" != "bulk" ]; then
+	test="run 'ipv6loganon' standard tests"
+	echo "INFO  : $test"
 	testscenarios_standard | grep -v "^#" | while read line; do
 
 		# extract result
@@ -136,30 +151,41 @@ if [ "$1" != "bulk" ]; then
 			echo "Something is wrong in line '$line'"
 			exit 1
 		fi
-		echo "IN     : $input"
-		echo "CHECK  : $result"
+		[ "$verbose" = "1" ] && echo "IN     : $input"
+		[ "$verbose" = "1" ] && echo "CHECK  : $result"
 		# get result
 		output="`echo "$input" | ./ipv6loganon -q`"
-		echo "OUT    : $output"
 		retval=$?
+		[ "$verbose" = "1" ] && echo "OUT    : $output"
 		if [ $retval -ne 0 ]; then
 			echo "Error executing 'ipv6loganon'!"
+			[ "$verbose" = "1" ] || echo "IN     : $input"
+			[ "$verbose" = "1" ] || echo "CHECK  : $result"
+			[ "$verbose" = "1" ] || echo "OUT    : $output"
 			exit 1
 		fi
 		# Check result
 		if [ "$result" != "*" ]; then
 			if [ "$output" != "$result" ]; then
+				[ "$verbose" = "1" ] || echo "IN     : $input"
+				[ "$verbose" = "1" ] || echo "CHECK  : $result"
+				[ "$verbose" = "1" ] || echo "OUT    : $output"
 				echo "RESULT : fail"
 				exit 1
 			fi
 		fi
-		echo "RESULT : ok"
-		echo
+		[ "$verbose" = "1" ] && echo "RESULT : ok"
+		[ "$verbose" = "1" ] && echo
+		[ "$verbose" = "1" ] || echo -n "."
 	done
 	retval=$?
+	[ "$verbose" = "1" ] || echo
+	echo "INFO  : $test successful"
 
 	if [ $retval -eq 0 ]; then
 		# special tests
+		test="run 'ipv6loganon' special tests"
+		echo "INFO  : $test"
 		testscenarios_special | grep -v "^#" | while read line; do
 
 			# extract result
@@ -170,28 +196,37 @@ if [ "$1" != "bulk" ]; then
 				echo "Something is wrong in line '$line'"
 				exit 1
 			fi
-			echo "IN     : $input"
-			echo "OPTIONS: $options"
-			echo "CHECK  : $result"
+			[ "$verbose" = "1" ] && echo "IN     : $input"
+			[ "$verbose" = "1" ] && echo "OPTIONS: $options"
+			[ "$verbose" = "1" ] && echo "CHECK  : $result"
 			# get result
 			output="`echo "$input" | ./ipv6loganon -q $options`"
-			echo "OUT    : $output"
 			retval=$?
+			[ "$verbose" = "1" ] && echo "OUT    : $output"
 			if [ $retval -ne 0 ]; then
 				echo "Error executing 'ipv6loganon'!"
+				[ "$verbose" = "1" ] || echo "IN     : $input"
+				[ "$verbose" = "1" ] || echo "CHECK  : $result"
+				[ "$verbose" = "1" ] || echo "OUT    : $output"
 				exit 1
 			fi
 			# Check result
 			if [ "$result" != "*" ]; then
 				if [ "$output" != "$result" ]; then
+					[ "$verbose" = "1" ] || echo "IN     : $input"
+					[ "$verbose" = "1" ] || echo "CHECK  : $result"
+					[ "$verbose" = "1" ] || echo "OUT    : $output"
 					echo "RESULT : fail"
 					exit 1
 				fi
 			fi
-			echo "RESULT : ok"
-			echo
+			[ "$verbose" = "1" ] && echo "RESULT : ok"
+			[ "$verbose" = "1" ] && echo
+			[ "$verbose" = "1" ] || echo -n "."
 		done
 		retval=$?
+		[ "$verbose" = "1" ] || echo
+		echo "INFO  : $test successful"
 	fi
 	echo 
 else
@@ -230,12 +265,12 @@ run_loganon_reliability_tests() {
 		return 1
 	fi
 
-	if ! ../ipv6logstats/ipv6logstats -v | grep -w STAT_REG; then
+	if ! ../ipv6logstats/ipv6logstats -v | grep -qw STAT_REG; then
 		echo "NOTICE: ipv6logstats misses basic database, skip tests"
 		return 0
 	fi
 
-	if ! ../ipv6logconv/ipv6logconv -v | grep -w CONV_REG; then
+	if ! ../ipv6logconv/ipv6logconv -v | grep -qw CONV_REG; then
 		echo "NOTICE: ipv6logconv misses basic database, skip tests"
 		return 0
 	fi
@@ -314,7 +349,8 @@ run_loganon_reliability_tests() {
 }
 
 run_loganon_options_tests() {
-	echo "Run 'ipv6loganon' anonymization option tests..."
+	test="run 'ipv6loganon' anonymization option tests"
+	echo "INFO  : $test"
 	testscenarios_anonymization_options | while read line; do
 		if [ -z "$line" ]; then
 			continue
@@ -323,8 +359,8 @@ run_loganon_options_tests() {
 		options="`echo $line | awk '{ for ( i = 1; i < NF; i++) printf "%s ", $i }'`"
 		input_result="`echo $line | awk '{ print $NF }'`"
 
-		echo "DEBUG : options=$options"
-		echo "DEBUG : input_result=$input_result"
+		[ "$verbose" = "1" ] && echo "DEBUG : options=$options"
+		[ "$verbose" = "1" ] && echo "DEBUG : input_result=$input_result"
 
 		input=${input_result/=*/}
 		result=${input_result/*=/}
@@ -343,9 +379,12 @@ run_loganon_options_tests() {
 			echo "ERROR : result expected: $result"
 			exit 1
 		else
-			echo "INFO  : $command -> test ok"
+			[ "$verbose" = "1" ] && echo "INFO  : $command -> test ok"
 		fi
+		[ "$verbose" = "1" ] || echo -n "."
 	done || return 1
+	[ "$verbose" = "1" ] || echo
+	echo "INFO  : $test successful"
 }
 
 run_loganon_options_kp_tests() {
