@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6logconv.c
- * Version    : $Id: ipv6logconv.c,v 1.36 2014/07/22 06:00:41 ds6peter Exp $
- * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6logconv.c,v 1.41 2015/05/26 15:50:04 ds6peter Exp $
+ * Copyright  : 2002-2015 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile conversions
@@ -72,6 +72,12 @@ int feature_ieee = 0;
 /**************************************************/
 /* main */
 int main(int argc,char *argv[]) {
+	/* check compatibility */
+#ifdef SHARED_LIBRARY
+	IPV6CALC_LIB_VERSION_CHECK_EXIT(IPV6CALC_PACKAGE_VERSION_NUMERIC, IPV6CALC_PACKAGE_VERSION_STRING)
+	IPV6CALC_DB_LIB_VERSION_CHECK_EXIT(IPV6CALC_PACKAGE_VERSION_NUMERIC, IPV6CALC_PACKAGE_VERSION_STRING)
+#endif // SHARED_LIBRARY
+
 	int i, lop, result;
 	unsigned long int command = 0;
 
@@ -84,9 +90,10 @@ int main(int argc,char *argv[]) {
 	long int action = -1;
 
 	/* options */
-	struct option longopts[MAXLONGOPTIONS];
+	struct option longopts[IPV6CALC_MAXLONGOPTIONS];
 	char   shortopts[NI_MAXHOST] = "";
 	int    longopts_maxentries = 0;
+	extern int optopt;
 
 	/* check for UID */
 	if (getuid() == 0) {
@@ -109,10 +116,17 @@ int main(int argc,char *argv[]) {
 		exit(EXIT_FAILURE);
 	};
 
+	/* initialize options from environment */
+	ipv6calc_common_options_from_env(longopts, NULL);
+
 	/* Fetch the command-line arguments. */
 	while ((i = getopt_long(argc, argv, shortopts, longopts, &lop)) != EOF) {
 		DEBUGPRINT_WA(DEBUG_ipv6logconv_general, "Parsing option: 0x%08x", i);
 
+		if ((i == '?') && (optopt != 0)) {
+			exit(EXIT_FAILURE);
+		};
+
 		/* catch common options */
 		result = ipv6calcoptions_common_basic(i, optarg, longopts);
 		if (result == 0) {
@@ -178,7 +192,7 @@ int main(int argc,char *argv[]) {
 	argc -= optind;
 
 	/* initialise database wrapper */
-	result = libipv6calc_db_wrapper_init();
+	result = libipv6calc_db_wrapper_init("");
 	if (result != 0) {
 		exit(EXIT_FAILURE);
 	};
@@ -228,6 +242,8 @@ int main(int argc,char *argv[]) {
 	/* call lineparser */
 	lineparser(outputtype);
 
+	libipv6calc_db_wrapper_cleanup();
+
 	exit(EXIT_SUCCESS);
 };
 
