@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc/ipv6logstats
  * File       : ipv6logstats.c
- * Version    : $Id: ipv6logstats.c,v 1.59 2014/07/30 20:31:43 ds6peter Exp $
- * Copyright  : 2003-2014 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6logstats.c,v 1.67 2015/05/31 15:34:55 ds6peter Exp $
+ * Copyright  : 2003-2015 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile statistics
@@ -13,7 +13,6 @@
 #include <stdlib.h> 
 #include <getopt.h> 
 #include <unistd.h>
-#include <math.h>
 #include <time.h>
 
 #include "config.h"
@@ -33,6 +32,11 @@
 #include "libifinet6.h"
 
 #include "../databases/lib/libipv6calc_db_wrapper.h"
+#include "../databases/lib/libipv6calc_db_wrapper_GeoIP.h"
+#include "../databases/lib/libipv6calc_db_wrapper_IP2Location.h"
+#include "../databases/lib/libipv6calc_db_wrapper_DBIP.h"
+#include "../databases/lib/libipv6calc_db_wrapper_External.h"
+#include "../databases/lib/libipv6calc_db_wrapper_BuiltIn.h"
 
 #define LINEBUFFER	16384
 
@@ -61,7 +65,7 @@ static stat_entries ipv6logstats_statentries[] = {
 	{ STATS_UNKNOWN		, 0, "UNKNOWN" },
 	{ STATS_IPV4_APNIC	, 0, "IPv4/APNIC" },
 	{ STATS_IPV4_ARIN	, 0, "IPv4/ARIN" },
-	{ STATS_IPV4_RIPE	, 0, "IPv4/RIPE" },
+	{ STATS_IPV4_RIPENCC	, 0, "IPv4/RIPE" },
 	{ STATS_IPV4_LACNIC	, 0, "IPv4/LACNIC" },
 	{ STATS_IPV4_AFRINIC	, 0, "IPv4/AFRINIC" },
 	{ STATS_IPV4_UNKNOWN	, 0, "IPv4/UNKNOWN" },
@@ -69,7 +73,7 @@ static stat_entries ipv6logstats_statentries[] = {
 	{ STATS_IPV6_IANA	, 0, "IPv6/IANA" },
 	{ STATS_IPV6_APNIC	, 0, "IPv6/APNIC" },
 	{ STATS_IPV6_ARIN	, 0, "IPv6/ARIN" },
-	{ STATS_IPV6_RIPE	, 0, "IPv6/RIPE" },
+	{ STATS_IPV6_RIPENCC    , 0, "IPv6/RIPE" },
 	{ STATS_IPV6_LACNIC	, 0, "IPv6/LACNIC" },
 	{ STATS_IPV6_AFRINIC	, 0, "IPv6/AFRINIC" },
 	{ STATS_IPV6_RESERVED	, 0, "IPv6/RESERVED" },
@@ -77,7 +81,7 @@ static stat_entries ipv6logstats_statentries[] = {
 	{ STATS_IPV6_6TO4_BASE + REGISTRY_IANA    , 0, "IPv6/6to4/IANA"     },
 	{ STATS_IPV6_6TO4_BASE + REGISTRY_APNIC   , 0, "IPv6/6to4/APNIC"    },
 	{ STATS_IPV6_6TO4_BASE + REGISTRY_ARIN    , 0, "IPv6/6to4/ARIN"     },
-	{ STATS_IPV6_6TO4_BASE + REGISTRY_RIPE    , 0, "IPv6/6to4/RIPE"     },
+	{ STATS_IPV6_6TO4_BASE + REGISTRY_RIPENCC , 0, "IPv6/6to4/RIPE"     },
 	{ STATS_IPV6_6TO4_BASE + REGISTRY_LACNIC  , 0, "IPv6/6to4/LACNIC"   },
 	{ STATS_IPV6_6TO4_BASE + REGISTRY_AFRINIC , 0, "IPv6/6to4/AFRINIC"  },
 	{ STATS_IPV6_6TO4_BASE + REGISTRY_RESERVED, 0, "IPv6/6to4/RESERVED" },
@@ -85,7 +89,7 @@ static stat_entries ipv6logstats_statentries[] = {
 	{ STATS_IPV6_TEREDO_BASE + REGISTRY_IANA    , 0, "IPv6/Teredo/IANA"     },
 	{ STATS_IPV6_TEREDO_BASE + REGISTRY_APNIC   , 0, "IPv6/Teredo/APNIC"    },
 	{ STATS_IPV6_TEREDO_BASE + REGISTRY_ARIN    , 0, "IPv6/Teredo/ARIN"     },
-	{ STATS_IPV6_TEREDO_BASE + REGISTRY_RIPE    , 0, "IPv6/Teredo/RIPE"     },
+	{ STATS_IPV6_TEREDO_BASE + REGISTRY_RIPENCC , 0, "IPv6/Teredo/RIPE"     },
 	{ STATS_IPV6_TEREDO_BASE + REGISTRY_LACNIC  , 0, "IPv6/Teredo/LACNIC"   },
 	{ STATS_IPV6_TEREDO_BASE + REGISTRY_AFRINIC , 0, "IPv6/Teredo/AFRINIC"  },
 	{ STATS_IPV6_TEREDO_BASE + REGISTRY_RESERVED, 0, "IPv6/Teredo/RESERVED" },
@@ -93,7 +97,7 @@ static stat_entries ipv6logstats_statentries[] = {
 	{ STATS_IPV6_NAT64_BASE + REGISTRY_IANA    , 0, "IPv6/NAT64/IANA"     },
 	{ STATS_IPV6_NAT64_BASE + REGISTRY_APNIC   , 0, "IPv6/NAT64/APNIC"    },
 	{ STATS_IPV6_NAT64_BASE + REGISTRY_ARIN    , 0, "IPv6/NAT64/ARIN"     },
-	{ STATS_IPV6_NAT64_BASE + REGISTRY_RIPE    , 0, "IPv6/NAT64/RIPE"     },
+	{ STATS_IPV6_NAT64_BASE + REGISTRY_RIPENCC , 0, "IPv6/NAT64/RIPE"     },
 	{ STATS_IPV6_NAT64_BASE + REGISTRY_LACNIC  , 0, "IPv6/NAT64/LACNIC"   },
 	{ STATS_IPV6_NAT64_BASE + REGISTRY_AFRINIC , 0, "IPv6/NAT64/AFRINIC"  },
 	{ STATS_IPV6_NAT64_BASE + REGISTRY_RESERVED, 0, "IPv6/NAT64/RESERVED" },
@@ -125,13 +129,20 @@ static void lineparser(void);
 /**************************************************/
 /* main */
 int main(int argc,char *argv[]) {
+	/* check compatibility */
+#ifdef SHARED_LIBRARY
+	IPV6CALC_LIB_VERSION_CHECK_EXIT(IPV6CALC_PACKAGE_VERSION_NUMERIC, IPV6CALC_PACKAGE_VERSION_STRING)
+	IPV6CALC_DB_LIB_VERSION_CHECK_EXIT(IPV6CALC_PACKAGE_VERSION_NUMERIC, IPV6CALC_PACKAGE_VERSION_STRING)
+#endif // SHARED_LIBRARY
+
 	int i, lop, result;
 	unsigned long int command = 0;
 
 	/* options */
-	struct option longopts[MAXLONGOPTIONS];
+	struct option longopts[IPV6CALC_MAXLONGOPTIONS];
 	char   shortopts[NI_MAXHOST] = "";
 	int    longopts_maxentries = 0;
+	extern int optopt;
 
 	/* check for UID */
 	if (getuid() == 0) {
@@ -149,8 +160,16 @@ int main(int argc,char *argv[]) {
 	ipv6calc_options_add_common_basic(shortopts, sizeof(shortopts), longopts, &longopts_maxentries);
 	ipv6calc_options_add(shortopts, sizeof(shortopts), longopts, &longopts_maxentries, ipv6logstats_shortopts, ipv6logstats_longopts, MAXENTRIES_ARRAY(ipv6logstats_longopts));
 
+	/* initialize options from environment */
+	ipv6calc_common_options_from_env(longopts, NULL);
+
 	/* Fetch the command-line arguments. */
 	while ((i = getopt_long(argc, argv, shortopts, longopts, &lop)) != EOF) {
+		DEBUGPRINT_WA(DEBUG_ipv6logstats_general, "Parsing option: 0x%08x", i);
+
+		if ((i == '?') && (optopt != 0)) {
+			exit(EXIT_FAILURE);
+		};
 
 		/* catch common options */
 		result = ipv6calcoptions_common_basic(i, optarg, longopts);
@@ -237,7 +256,7 @@ int main(int argc,char *argv[]) {
 	argc -= optind;
 
         /* initialise database wrapper */
-	result = libipv6calc_db_wrapper_init();
+	result = libipv6calc_db_wrapper_init("*3*DB-Info: ");
 	if (result != 0) {
 		exit(EXIT_FAILURE);
 	};
@@ -287,6 +306,8 @@ int main(int argc,char *argv[]) {
 	/* call lineparser */
 	lineparser();
 
+	libipv6calc_db_wrapper_cleanup();
+
 	exit(EXIT_SUCCESS);
 };
 
@@ -530,7 +551,7 @@ static void lineparser(void) {
 					};
 
 					if (opt_simple != 1) {
-						cc_index = libipv4addr_cc_index_by_addr(&ipv4addr);
+						cc_index = libipv4addr_cc_index_by_addr(&ipv4addr, NULL);
 						as_num32 = libipv4addr_as_num32_by_addr(&ipv4addr);
 						if (feature_cc == 1) {
 							stat_inc_country_code(cc_index, 4);
@@ -564,8 +585,8 @@ static void lineparser(void) {
 							case IPV4_ADDR_REGISTRY_ARIN:
 								stat_inc(stat_registry_base + REGISTRY_ARIN);
 								break;
-							case IPV4_ADDR_REGISTRY_RIPE:
-								stat_inc(stat_registry_base + REGISTRY_RIPE);
+							case IPV4_ADDR_REGISTRY_RIPENCC:
+								stat_inc(stat_registry_base + REGISTRY_RIPENCC);
 								break;
 							case IPV4_ADDR_REGISTRY_LACNIC:
 								stat_inc(stat_registry_base + REGISTRY_LACNIC);
@@ -590,7 +611,7 @@ static void lineparser(void) {
 					};
 				} else {
 					if (opt_simple != 1) {
-						cc_index = libipv6addr_cc_index_by_addr(&ipv6addr);
+						cc_index = libipv6addr_cc_index_by_addr(&ipv6addr, NULL);
 						as_num32 = libipv6addr_as_num32_by_addr(&ipv6addr);
 
 						if (feature_cc == 1) {
@@ -619,8 +640,8 @@ static void lineparser(void) {
 						case IPV6_ADDR_REGISTRY_ARIN:
 							stat_inc(STATS_IPV6_ARIN);
 							break;
-						case IPV6_ADDR_REGISTRY_RIPE:
-							stat_inc(STATS_IPV6_RIPE);
+						case IPV6_ADDR_REGISTRY_RIPENCC:
+							stat_inc(STATS_IPV6_RIPENCC);
 							break;
 						case IPV6_ADDR_REGISTRY_LACNIC:
 							stat_inc(STATS_IPV6_LACNIC);
@@ -661,7 +682,7 @@ static void lineparser(void) {
 				stat_inc(STATS_IPV4);
 
 				if (opt_simple != 1) {
-					cc_index = libipv4addr_cc_index_by_addr(&ipv4addr);
+					cc_index = libipv4addr_cc_index_by_addr(&ipv4addr, NULL);
 					as_num32 = libipv4addr_as_num32_by_addr(&ipv4addr);
 
 					stat_inc_country_code(cc_index, 4);
@@ -680,8 +701,8 @@ static void lineparser(void) {
 					case IPV4_ADDR_REGISTRY_ARIN:
 						stat_inc(STATS_IPV4_ARIN);
 						break;
-					case IPV4_ADDR_REGISTRY_RIPE:
-						stat_inc(STATS_IPV4_RIPE);
+					case IPV4_ADDR_REGISTRY_RIPENCC:
+						stat_inc(STATS_IPV4_RIPENCC);
 						break;
 					case IPV4_ADDR_REGISTRY_LACNIC:
 						stat_inc(STATS_IPV4_LACNIC);
@@ -857,5 +878,49 @@ static void lineparser(void) {
 		};
 	};
 
+
+	if (opt_printdirection == 0) {
+		/* print used database only in row mode */
+
+#if defined SUPPORT_IP2LOCATION || defined SUPPORT_GEOIP || defined SUPPORT_DBIP || defined SUPPORT_EXTERNAL || defined SUPPORT_BUILTIN
+		char *string;
+#endif
+
+#ifdef SUPPORT_IP2LOCATION
+		string = libipv6calc_db_wrapper_IP2Location_wrapper_db_info_used();
+		if ((string != NULL) && (strlen(string) > 0)) {
+			printf("*3*DB-Used: %s\n", string);
+		};
+#endif
+
+#ifdef SUPPORT_GEOIP
+		string = libipv6calc_db_wrapper_GeoIP_wrapper_db_info_used();
+		if ((string != NULL) && (strlen(string) > 0)) {
+			printf("*3*DB-Used: %s\n", string);
+		};
+#endif
+
+#ifdef SUPPORT_DBIP
+		string = libipv6calc_db_wrapper_DBIP_wrapper_db_info_used();
+		if ((string != NULL) && (strlen(string) > 0)) {
+			printf("*3*DB-Used: %s\n", string);
+		};
+#endif
+
+#ifdef SUPPORT_EXTERNAL
+		string = libipv6calc_db_wrapper_External_wrapper_db_info_used();
+		if ((string != NULL) && (strlen(string) > 0)) {
+			printf("*3*DB-Used: %s\n", string);
+		};
+#endif
+
+#ifdef SUPPORT_BUILTIN
+		string = libipv6calc_db_wrapper_BuiltIn_wrapper_db_info_used();
+		if ((string != NULL) && (strlen(string) > 0)) {
+			printf("*3*DB-Used: %s\n", string);
+		};
+#endif
+	};
+
 	return;
 };
