@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calchelp.c
- * Version    : $Id: ipv6calchelp.c,v 1.68 2014/09/24 09:07:57 ds6peter Exp $
- * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6calchelp.c,v 1.82 2015/08/23 09:53:27 ds6peter Exp $
+ * Copyright  : 2002-2015 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Help library
@@ -207,7 +207,7 @@ void printhelp_outputtypes(const uint32_t inputtype, const uint32_t formatoption
 
 /* list of action types */
 void printhelp_actiontypes(const uint32_t formatoptions, const struct option longopts[]) {
-	int i, j, o, test = 2, has_options = 0;
+	int i, j, o, test, has_options;
 	size_t maxlen = 0;
 	char printformatstring[20], printformatstring2[20], printformatstring3[20];
 	
@@ -237,19 +237,21 @@ void printhelp_actiontypes(const uint32_t formatoptions, const struct option lon
 	snprintf(printformatstring2, sizeof(printformatstring2), "  %%-%ds%%s\n", (int) maxlen + 4);
 	snprintf(printformatstring3, sizeof(printformatstring3), "  %%-%ds--%%s", (int) maxlen + 5);
 
-	DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Format string: %s", printformatstring);
+	DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Action string: %s", printformatstring);
 
 	if ((formatoptions & FORMATOPTION_machinereadable) == 0) fprintf(stderr, "\n Available action types:\n");
 
 	for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_actionstrings); j++) {
-		DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Format-Row %d: %08x - %s - %s", j, (unsigned int) ipv6calc_actionstrings[j].number, ipv6calc_actionstrings[j].token, ipv6calc_actionstrings[j].explanation);
+		DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Action-Row %d: %08x - %s - %s", j, (unsigned int) ipv6calc_actionstrings[j].number, ipv6calc_actionstrings[j].token, ipv6calc_actionstrings[j].explanation);
 
 		if ((formatoptions & FORMATOPTION_machinereadable) == 0) {
 			fprintf(stderr, printformatstring, ipv6calc_actionstrings[j].token, ipv6calc_actionstrings[j].explanation);
 
+			test = 2;
+			has_options = 0;
 			while (test != 0) {
 				if (test == 1) {	
-					fprintf(stderr, printformatstring2, "", "Required options:");
+					fprintf(stderr, printformatstring2, "", "Options:");
 				};
 
 				/* search for defined options */
@@ -274,6 +276,11 @@ void printhelp_actiontypes(const uint32_t formatoptions, const struct option lon
 									if (longopts[o].has_arg > 0) {
 										fprintf(stderr, " ...");
 									};
+									if (ipv6calc_actionoptionmap[i][2] > 0) {
+										fprintf(stderr, " (optional)");
+									} else {
+										fprintf(stderr, " (required)");
+									};
 									fprintf(stderr, "\n");
 								};
 							};
@@ -318,6 +325,13 @@ void printhelp_common(const uint32_t help_features) {
 #ifdef SUPPORT_IP2LOCATION_DYN
 		fprintf(stderr, "  [--db-ip2location-lib <file>     ] : IP2Location library file (default: %s)\n", ip2location_lib_file);
 #endif
+		fprintf(stderr, "  [--db-ip2location-only-type <TYPE>]: IP2Location database only selected type (1-%d)\n", IP2LOCATION_DB_MAX);
+		fprintf(stderr, "  [--db-ip2location-allow-softlinks] : IP2Location database softlinks allowed\n");
+		fprintf(stderr, "     by default they are ignored because it is hard to autodetect COMM/LITE/SAMPLE\n");
+		fprintf(stderr, "  [--db-ip2location-lite-to-sample-autoswitch-max-delta-months <MONTHS>]:\n");
+		fprintf(stderr, "     autoswitch from LITE to SAMPLE databases if possible and delta is not more than %d months (0=disabled)\n", ip2location_db_lite_to_sample_autoswitch_max_delta_months);
+		fprintf(stderr, "  [--db-ip2location-comm-to-lite-switch-min-delta-months <MONTHS>]:\n");
+		fprintf(stderr, "     switch from COMM to LITE databases if possible and delta more than %d months (0=disabled)\n", ip2location_db_comm_to_lite_switch_min_delta_months);
 #endif
 	};
 
@@ -357,6 +371,17 @@ void printhelp_common(const uint32_t help_features) {
 		fprintf(stderr, "  [--disable-builtin               ] : BuiltIn support disabled\n");
 		fprintf(stderr, "  [--db-builtin-disable            ] : BuiltIn support disabled\n");
 #endif
+
+#if defined SUPPORT_EXTERNAL || defined SUPPORT_DBIP || defined SUPPORT_GEOIP || SUPPORT_IP2LOCATION
+		fprintf(stderr, "\n");
+		fprintf(stderr, "  [--db-priorization <entry1>[:...]] : Database priorization order list (overwrites default)\n");
+		fprintf(stderr, "                                         colon separated:");
+		int i;
+		for (i = 0; i < MAXENTRIES_ARRAY(data_sources); i++) {
+			fprintf(stderr, " %s", data_sources[i].shortname);
+		};
+		fprintf(stderr, "\n");
+#endif
 	};
 
 	fprintf(stderr, "\n");
@@ -646,7 +671,19 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			break;
 			
 		case ACTION_ipv4_to_6to4addr:
-			fprintf(stderr, " help still missing - sorry.\n");
+			fprintf(stderr, "  Convert IPv4 to 6to4 prefix / extract IPv4 from 6to4 prefix\n");
+			fprintf(stderr, "   ipv6calc -A conv6to4 192.0.2.1\n");
+			fprintf(stderr, "    2002:c000:201::\n");
+			fprintf(stderr, "   ipv6calc -A conv6to4 2002:c000:201::\n");
+			fprintf(stderr, "    192.0.2.1\n");
+			break;
+
+		case ACTION_ipv4_to_nat64:
+			fprintf(stderr, "  Convert IPv4 to NAT64 address / extract IPv4 from NAT64 address\n");
+			fprintf(stderr, "   ipv6calc -A convnat64 192.0.2.1\n");
+			fprintf(stderr, "    64:ff9b::c000:201\n");
+			fprintf(stderr, "   ipv6calc -A convnat64 64:ff9b::c000:201\n");
+			fprintf(stderr, "    192.0.2.1\n");
 			break;
 
 		case ACTION_anonymize:
@@ -711,10 +748,12 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			fprintf(stderr, " Filter given addresses from stdout by filter expression, e.g.\n");
 			fprintf(stderr, "  echo '2001:db8::1' | ipv6calc [-A filter] -E iid-local\n");
 			fprintf(stderr, "  echo '2001:db8::1' | ipv6calc [-A filter] -E iid-local,global-unicast\n");
-			fprintf(stderr, "  echo '2001:db8::1' | ipv6calc [-A filter] -E ^iid-randomy\n");
+			fprintf(stderr, "  echo '2001:db8::1' | ipv6calc [-A filter] -E ^iid-random\n");
 			fprintf(stderr, "\n");
 			fprintf(stderr, " (note: since version 0.95.0 '-A filter' is autoselected if option '-E <filter expression>' is given)\n");
 			fprintf(stderr, "\n");
+			fprintf(stderr, " negation of filter expression with prefix: ^\n");
+			fprintf(stderr, "\n");
 			fprintf(stderr, "  IPv6 address filter tokens:\n");
 			fprintf(stderr, "   ipv6 ");
 			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++ ) {
@@ -729,6 +768,20 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			};
 			fprintf(stderr, "\n");
 			fprintf(stderr, "\n");
+			fprintf(stderr, "  IPv4/v6 address filter tokens based on databases:\n");
+			fprintf(stderr, "   [^][ipv4.|ipv6.]db.cc=<CC>|unknown (Country Code [2 chars])\n");
+			fprintf(stderr, "   [^][ipv4.|ipv6.]db.asn=<ASN>|unknown (Autonomous System Number)\n");
+			fprintf(stderr, "   [^][ipv4.|ipv6.]db.reg=<REGISTRY>\n");
+			fprintf(stderr, "    Registry tokens:");
+			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_registries); i++ ) {
+				fprintf(stderr, " %s", ipv6calc_registries[i].token);
+			};
+			fprintf(stderr, "\n");
+			fprintf(stderr, "\n");
+			fprintf(stderr, "  IPv4/v6 address filter tokens based on address/mask:\n");
+			fprintf(stderr, "   [^]ipv4.addr=<IPV4-ADDRESS>[<PREFIX-LENGTH>]\n");
+			fprintf(stderr, "   [^]ipv6.addr=<IPV6-ADDRESS>[<PREFIX-LENGTH>]\n");
+			fprintf(stderr, "\n");
 			fprintf(stderr, "  EUI-48/MAC address filter tokens:\n");
 			fprintf(stderr, "   ");
 			fprintf(stderr, " IMPLEMENTATION MISSING");
@@ -754,6 +807,40 @@ void ipv6calc_print_features_verbose(const int level_verbose) {
 	libipv6calc_db_wrapper_capabilities(string, sizeof(string));
 	fprintf(stderr, "Capabilities: %s\n\n", string);
 
+	fprintf(stderr, "Internal main     library version: %s  API: %s  (%s)\n"
+		, libipv6calc_lib_version_string()
+		, libipv6calc_api_version_string()
+#ifdef SHARED_LIBRARY
+		, "shared"
+#else  // SHARED_LIBRARY
+		, "built-in"
+#endif // SHARED_LIBRARY
+	);
+
+	fprintf(stderr, "Internal database library version: %s  API: %s  (%s)\n\n"
+		, libipv6calc_db_lib_version_string()
+		, libipv6calc_db_api_version_string()
+#ifdef SHARED_LIBRARY
+		, "shared"
+#else  // SHARED_LIBRARY
+		, "built-in"
+#endif // SHARED_LIBRARY
+	);
+
+#if defined ENABLE_BUNDLED_MD5 || defined ENABLE_BUNDLED_GETOPT
+	fprintf(stderr, "Bundled with:");
+#ifdef ENABLE_BUNDLED_MD5
+	fprintf(stderr, " MD5");
+#endif
+#ifdef ENABLE_BUNDLED_GETOPT
+	fprintf(stderr, " GETOPT");
+#endif
+	fprintf(stderr, "\n\n");
+#endif
+
+	fprintf(stderr, "Compiled: %s  %s\n\n", __DATE__, __TIME__);
+
+
 #ifdef SUPPORT_GEOIP
 #ifdef GEOIP_INCLUDE_VERSION
 	fprintf(stderr, "GeoIP support enabled, compiled with include file version: %s\n", GEOIP_INCLUDE_VERSION);
@@ -793,7 +880,7 @@ void ipv6calc_print_features_verbose(const int level_verbose) {
 #endif
 
 #ifdef SUPPORT_IP2LOCATION
-#ifdef GEOIP_INCLUDE_VERSION
+#ifdef IP2LOCATION_INCLUDE_VERSION
 	fprintf(stderr, "IP2Location support enabled, compiled with include file version: %s\n", IP2LOCATION_INCLUDE_VERSION);
 #endif
 	fprintf(stderr, "IP2Location support enabled, compiled with API version: %s\n", xmakestr(API_VERSION));
