@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calcoptions.h
- * Version    : $Id: ipv6calcoptions_common.h,v 1.13 2014/09/24 09:07:58 ds6peter Exp $
- * Copyright  : 2013-2014 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6calcoptions_common.h,v 1.17 2015/05/26 15:50:04 ds6peter Exp $
+ * Copyright  : 2013-2015 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file containing options
@@ -43,6 +43,13 @@ static struct option ipv6calc_longopts_ip2location[] = {
 	{"disable-ip2location"         , 0, NULL, DB_ip2location_disable },
 	{"db-ip2location-disable"      , 0, NULL, DB_ip2location_disable },
 	{"db-ip2location-dir"          , 1, NULL, DB_ip2location_dir     },
+
+	/* database selection control */
+	{"db-ip2location-lite-to-sample-autoswitch-max-delta-months", 1, NULL, DB_ip2location_lite_to_sample_autoswitch_max_delta_months },
+	{"db-ip2location-comm-to-lite-switch-min-delta-months", 1, NULL, DB_ip2location_comm_to_lite_switch_min_delta_months },
+	{"db-ip2location-only-type", 1, NULL, DB_ip2location_only_type },
+	{"db-ip2location-allow-softlinks", 0, NULL, DB_ip2location_allow_softlinks },
+
 #ifdef SUPPORT_IP2LOCATION_DYN
 	{"db-ip2location-lib"          , 1, NULL, DB_ip2location_lib     },
 #endif // SUPPORT_IP2LOCATION_DYN
@@ -100,6 +107,14 @@ static struct option ipv6calc_longopts_builtin[] = {
 };
 #endif // SUPPORT_BUILTIN
 
+#if defined SUPPORT_EXTERNAL || defined SUPPORT_DBIP || defined SUPPORT_GEOIP || SUPPORT_IP2LOCATION
+static char *ipv6calc_shortopts_db_common = "";
+
+static struct option ipv6calc_longopts_db_common[] = {
+	{"db-priorization"             , 1, NULL, DB_common_priorization },
+};
+#endif
+
 /* define common anonymization short options */
 static char *ipv6calc_shortopts_common_anon = "";
 
