@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calctypes.h
- * Version    : $Id: ipv6calctypes.h,v 1.43 2014/10/07 20:25:23 ds6peter Exp $
- * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6calctypes.h,v 1.53 2015/08/23 09:53:27 ds6peter Exp $
+ * Copyright  : 2002-2015 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file for ipv6calctypes.c
@@ -13,10 +13,6 @@
 #include <getopt.h>
 
 
-/* prototypes */
-extern uint32_t ipv6calctypes_checktype(const char *string);
-extern uint32_t ipv6calctypes_checkaction(const char *string);
-
 /* defines */
 #ifndef _ipv6calctypes_h_
 
@@ -66,6 +62,7 @@ typedef struct {
 #define FORMAT_NUM_octal		21
 #define FORMAT_NUM_hex			22
 #define FORMAT_NUM_ipv6literal		23
+#define FORMAT_NUM_ipv6rd		24
 #define FORMAT_NUM_asn			29
 #define FORMAT_NUM_auto_noresult	30
 #define FORMAT_NUM_undefined		31
@@ -174,10 +171,17 @@ typedef struct {
 #define FORMATOPTION_NUM_machinereadable	12	// 00001000
 #define FORMATOPTION_NUM_quiet			13	// 00002000
 #define FORMATOPTION_NUM_printmirrored		14	// 00004000
-#define FORMATOPTION_NUM_forceprefix		15	// 00010000
-#define FORMATOPTION_NUM_literal		16	// 00020000
-#define FORMATOPTION_NUM_print_iid_var		17	// 00040000
-#define FORMATOPTION_NUM_no_prefixlength	18	// 00080000
+#define FORMATOPTION_NUM_forceprefix		15	// 00008000
+#define FORMATOPTION_NUM_literal		16	// 00010000
+#define FORMATOPTION_NUM_print_iid_var		17	// 00020000
+#define FORMATOPTION_NUM_no_prefixlength	18	// 00040000
+#define FORMATOPTION_NUM_mr_quote_always	19	// 00080000
+#define FORMATOPTION_NUM_mr_quote_never		20	// 00100000
+#define FORMATOPTION_NUM_mr_value_only		21	// 00200000
+#define FORMATOPTION_NUM_mr_select_token	22	// 00400000
+#define FORMATOPTION_NUM_mr_select_token_pa	23	// 00800000
+#define FORMATOPTION_NUM_mr_match_token		24	// 01000000
+#define FORMATOPTION_NUM_mr_quote_default	25	// 02000000 flag for controlling old quote behavior < 0.99.0
 
 #define FORMATOPTION_NUM_printembedded		31	// special
 
@@ -199,6 +203,13 @@ typedef struct {
 #define FORMATOPTION_literal			(uint32_t) (1 << FORMATOPTION_NUM_literal)
 #define FORMATOPTION_print_iid_var		(uint32_t) (1 << FORMATOPTION_NUM_print_iid_var)
 #define FORMATOPTION_no_prefixlength		(uint32_t) (1 << FORMATOPTION_NUM_no_prefixlength)
+#define FORMATOPTION_mr_quote_always		(uint32_t) (1 << FORMATOPTION_NUM_mr_quote_always)
+#define FORMATOPTION_mr_quote_never		(uint32_t) (1 << FORMATOPTION_NUM_mr_quote_never)
+#define FORMATOPTION_mr_value_only		(uint32_t) (1 << FORMATOPTION_NUM_mr_value_only)
+#define FORMATOPTION_mr_select_token		(uint32_t) (1 << FORMATOPTION_NUM_mr_select_token)
+#define FORMATOPTION_mr_select_token_pa		(uint32_t) (1 << FORMATOPTION_NUM_mr_select_token_pa)
+#define FORMATOPTION_mr_match_token		(uint32_t) (1 << FORMATOPTION_NUM_mr_match_token)
+#define FORMATOPTION_mr_quote_default		(uint32_t) (1 << FORMATOPTION_NUM_mr_quote_default) // flag for controlling old quote behavior < 0.99.0
 
 #define FORMATOPTION_printembedded		(uint32_t) (1 << FORMATOPTION_NUM_printembedded)
 
@@ -256,7 +267,9 @@ typedef struct {
 #define ACTION_NUM_prefix_mac_to_ipv6	4
 #define ACTION_NUM_anonymize		5
 #define ACTION_NUM_6rd_local_prefix	6
-#define ACTION_NUM_filter		7
+#define ACTION_NUM_6rd_extract_ipv4	7
+#define ACTION_NUM_ipv4_to_nat64	8
+#define ACTION_NUM_filter		15
 #define ACTION_NUM_undefined		31
 
 #define ACTION_auto			(uint32_t) 0x0
@@ -266,6 +279,8 @@ typedef struct {
 #define ACTION_prefix_mac_to_ipv6	(uint32_t) (1 << ACTION_NUM_prefix_mac_to_ipv6)
 #define ACTION_anonymize		(uint32_t) (1 << ACTION_NUM_anonymize)
 #define ACTION_6rd_local_prefix		(uint32_t) (1 << ACTION_NUM_6rd_local_prefix)
+#define ACTION_6rd_extract_ipv4		(uint32_t) (1 << ACTION_NUM_6rd_extract_ipv4)
+#define ACTION_ipv4_to_nat64		(uint32_t) (1 << ACTION_NUM_ipv4_to_nat64)
 #define ACTION_filter			(uint32_t) (1 << ACTION_NUM_filter)
 #define ACTION_undefined		(uint32_t) (1 << ACTION_NUM_undefined)
 
@@ -284,26 +299,29 @@ typedef struct {
 	{ ACTION_auto                 , "auto"            , "Automatic selection of action (default)", "" },
 	{ ACTION_mac_to_eui64         , "geneui64"        , "Converts a MAC address to an EUI-64 address", "" },
 	{ ACTION_ipv4_to_6to4addr     , "conv6to4"        , "Converts IPv4 address <-> 6to4 IPv6 address (prefix)", "" },
+	{ ACTION_ipv4_to_nat64        , "convnat64"       , "Converts IPv4 address <-> NAT64 IPv6 address", "" },
 	{ ACTION_iid_token_to_privacy , "genprivacyiid"   , "Generates a privacy interface ID out of a given one (arg1) and a token (arg2)", "" },
 	{ ACTION_prefix_mac_to_ipv6   , "prefixmac2ipv6"  , "Generates an IPv6 address out of a prefix and a MAC address", "" },
 	{ ACTION_anonymize            , "anonymize"       , "Anonymize IPv4/IPv6 address without loosing much information", "" },
-	{ ACTION_6rd_local_prefix     , "6rd_local_prefix", "Calculate the 6rd prefix from given IPv6 prefix & relay prefix and IPv4", "" },
+	{ ACTION_6rd_local_prefix     , "6rd_local_prefix", "Calculate the 6rd prefix from given IPv6 prefix (& relay prefix) and IPv4", "" },
+	{ ACTION_6rd_extract_ipv4     , "6rd_extract_ipv4", "Extract from 6rd address the include IPv4 address", "" },
 	{ ACTION_filter	              , "filter"          , "Filter addresses related to filter options", "" },
 };
 
-/* Possible action option map */
-/*@unused@*/ static const uint32_t ipv6calc_actionoptionmap[8][2]  = {
-	{ ACTION_auto			, 0 },
-	{ ACTION_mac_to_eui64		, 0 },
-	{ ACTION_ipv4_to_6to4addr	, 0 },
-	{ ACTION_iid_token_to_privacy	, 0 },
-	{ ACTION_prefix_mac_to_ipv6	, 0 },
-	{ ACTION_anonymize		, 0 },
-	{ ACTION_6rd_local_prefix	, CMD_6rd_prefix },
-	{ ACTION_6rd_local_prefix	, CMD_6rd_relay_prefix }
+/* Possible action option map (required) */
+/*@unused@*/ static const uint32_t ipv6calc_actionoptionmap[][3]  = {
+	{ ACTION_auto			, 0 , 0},
+	{ ACTION_mac_to_eui64		, 0 , 0},
+	{ ACTION_ipv4_to_6to4addr	, 0 , 0},
+	{ ACTION_ipv4_to_nat64		, 0 , 0},
+	{ ACTION_iid_token_to_privacy	, 0 , 0},
+	{ ACTION_prefix_mac_to_ipv6	, 0 , 0},
+	{ ACTION_anonymize		, 0 , 0},
+	{ ACTION_6rd_local_prefix	, CMD_6rd_prefix, 0},
+	{ ACTION_6rd_local_prefix	, CMD_6rd_relay_prefix, 1 },
+	{ ACTION_6rd_extract_ipv4	, CMD_6rd_prefixlength, 0},
 };
 
-
 /* anonymization set */
 typedef struct {
 	char name[32];
@@ -323,4 +341,56 @@ typedef struct {
 	const char description[128];
 } s_ipv6calc_anon_methods;
 
+
+/**** filter structures ****/
+#define IPV6CALC_FILTER_DB_CC_MAX	16
+#define IPV6CALC_FILTER_DB_ASN_MAX	16
+#define IPV6CALC_FILTER_DB_REGISTRY_MAX	8
+#define IPV6CALC_FILTER_IPV4ADDR	16
+#define IPV6CALC_FILTER_IPV6ADDR	16
+
+/* DB CC (CountryCode) filter structure */
+typedef struct {
+	int active;
+	int cc_must_have_max;
+	int cc_may_not_have_max;
+	uint16_t cc_must_have[IPV6CALC_FILTER_DB_CC_MAX];
+	uint16_t cc_may_not_have[IPV6CALC_FILTER_DB_CC_MAX];
+} s_ipv6calc_filter_db_cc;
+
+
+/* DB ASN (Autonomous System Number) filter structure */
+typedef struct {
+	int active;
+	int asn_must_have_max;
+	int asn_may_not_have_max;
+	uint32_t asn_must_have[IPV6CALC_FILTER_DB_ASN_MAX];
+	uint32_t asn_may_not_have[IPV6CALC_FILTER_DB_ASN_MAX];
+} s_ipv6calc_filter_db_asn;
+
+
+/* DB Registry filter structure */
+typedef struct {
+	int active;
+	int registry_must_have_max;
+	int registry_may_not_have_max;
+	uint32_t registry_must_have[IPV6CALC_FILTER_DB_REGISTRY_MAX];
+	uint32_t registry_may_not_have[IPV6CALC_FILTER_DB_REGISTRY_MAX];
+} s_ipv6calc_filter_db_registry;
+
+/* typeinfo filter structure */
+typedef struct {
+	int active;
+	uint32_t typeinfo_must_have;
+	uint32_t typeinfo_may_not_have;
+} s_ipv6calc_filter_typeinfo;
+
+
 #endif // _ipv6calctypes_h_
+
+
+/* prototypes */
+extern uint32_t ipv6calctypes_checktype(const char *string);
+extern uint32_t ipv6calctypes_checkaction(const char *string);
+
+extern const char *ipv6calctypes_format_string_by_type(const uint32_t format_type);
