@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc/lib
  * File       : libipv4addr.c
- * Version    : $Id: libipv4addr.c,v 1.63 2014/10/07 20:25:23 ds6peter Exp $
- * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
+ * Version    : $Id: libipv4addr.c,v 1.67 2015/05/29 05:42:07 ds6peter Exp $
+ * Copyright  : 2002-2015 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  *
  * Information:
  *  Function library for IPv4 address handling
@@ -33,11 +33,11 @@ uint8_t ipv4addr_getoctet(const ipv6calc_ipv4addr *ipv4addrp, const unsigned int
 	uint8_t retval;
 	
 	if ( numoctet > 3 ) {
-		fprintf(stderr, "%s/%s: given octet number '%u' is out of range!\n", __FILE__, __func__, numoctet);
+		ERRORPRINT_WA("given octet number '%u' is out of range!\n", numoctet);
 		exit(EXIT_FAILURE);
 	};
 
-	retval = (uint8_t) ( (ipv4addrp->in_addr.s_addr >> ( (unsigned int) (3 - numoctet) << 3)) & 0xff );
+	retval = (uint8_t) ( (ipv4addrp->in_addr.s_addr >> ( numoctet << 3)) & 0xff );
 
 	return (retval);
 };
@@ -94,8 +94,8 @@ void ipv4addr_setoctet(ipv6calc_ipv4addr *ipv4addrp, const unsigned int numoctet
 		exit(EXIT_FAILURE);
 	};
 	
-	ipv4addrp->in_addr.s_addr &= ~ (0xff << ((unsigned int) (3 - numoctet) << 3) );
-	ipv4addrp->in_addr.s_addr |= (value & 0xff) << ((unsigned int) (3 - numoctet) << 3);
+	ipv4addrp->in_addr.s_addr &= ~ (0xff << (numoctet << 3) );
+	ipv4addrp->in_addr.s_addr |= (value & 0xff) << (numoctet << 3);
 
 	return;
 };
@@ -202,8 +202,8 @@ void ipv4addr_clearall(ipv6calc_ipv4addr *ipv4addrp) {
 /*
  * function copies the IPv4 structure
  *
- * in:  ipv64ddrp  = pointer to IPv4 address structure
- * mod: ipv64ddrp2 = pointer to IPv4 address structure
+ * in:  ipv4addrp_src = pointer to IPv4 address structure
+ * mod: ipv4addrp_dst = pointer to IPv4 address structure
  */
 void ipv4addr_copy(ipv6calc_ipv4addr *ipv4addrp_dst, const ipv6calc_ipv4addr *ipv4addrp_src) {
 
@@ -213,6 +213,36 @@ void ipv4addr_copy(ipv6calc_ipv4addr *ipv4addrp_dst, const ipv6calc_ipv4addr *ip
 };
 
 
+/*
+ * function compares the IPv4 structure
+ *
+ * in:  ipv4addrp1  = pointer to IPv4 address structure
+ * in:  ipv4addrp2  = pointer to IPv4 address structure
+ * in:  compare_flags: 0=honor prefix length on addr1 TODO: add more support if required
+ * returns: 0 = addr2 equal with addr1 or covered by addr1
+ */
+int ipv4addr_compare(const ipv6calc_ipv4addr *ipv4addrp1, const ipv6calc_ipv4addr *ipv4addrp2, const uint16_t compare_flags) {
+	uint32_t ipv4addr1 = ipv4addr_getdword(ipv4addrp1);
+	uint32_t ipv4addr2 = ipv4addr_getdword(ipv4addrp2);
+
+	DEBUGPRINT_WA(DEBUG_libipv4addr, "compare addr1 with addr2 0x%08x/%d 0x%08x/%d", ipv4addr1, ipv4addrp1->prefixlength, ipv4addr2, ipv4addrp2->prefixlength);
+
+	if (ipv4addrp1->flag_prefixuse == 1) {
+		/* mask addr2 with prefix length of addr1 */
+		ipv4addr2 &= (0xffffffffu << ((unsigned int) 32 - ipv4addrp1->prefixlength));
+		/* mask addr1 with prefix length of addr1 */
+		ipv4addr1 &= (0xffffffffu << ((unsigned int) 32 - ipv4addrp1->prefixlength));
+	};
+
+	DEBUGPRINT_WA(DEBUG_libipv4addr, "compare addr1 with addr2 0x%08x 0x%08x (after masking with prefix length of addr1)", ipv4addr1, ipv4addr2);
+
+	if (ipv4addr1 == ipv4addr2) {
+		return(0);
+	};
+	return(1);
+};
+
+
 /*
  * function gets type of an IPv4 address
  */
@@ -573,13 +603,17 @@ int libipv4addr_ipv4addrstruct_to_string(const ipv6calc_ipv4addr *ipv4addrp, cha
 	/* address */
 	snprintf(tempstring, sizeof(tempstring), "%u.%u.%u.%u", (unsigned int) ipv4addr_getoctet(ipv4addrp, 0), (unsigned int) ipv4addr_getoctet(ipv4addrp, 1), (unsigned int) ipv4addr_getoctet(ipv4addrp, 2), (unsigned int) ipv4addr_getoctet(ipv4addrp, 3));
 
-	if ( (formatoptions & FORMATOPTION_machinereadable) != 0 ) {
+	if ((formatoptions & FORMATOPTION_machinereadable) != 0) {
 		snprintf(resultstring, resultstring_length, "IPV4=%s", tempstring);
 	} else {
-		snprintf(resultstring, resultstring_length, "%s", tempstring);
+		if (ipv4addrp->flag_prefixuse == 1) {
+			snprintf(resultstring, resultstring_length, "%s/%d", tempstring, ipv4addrp->prefixlength);
+		} else {
+			snprintf(resultstring, resultstring_length, "%s", tempstring);
+		};
 	};
 
-	/* netmaks */
+	/* netmask/prefixlength */
 	if (ipv4addrp->flag_prefixuse == 1) {
 		/* to be filled */
 		/* IPV4NETMASK= */
@@ -883,8 +917,19 @@ uint16_t ipv4addr_anonymized_get_cc_index(const ipv6calc_ipv4addr *ipv4addrp) {
  */
 void ipv4addr_filter_clear(s_ipv6calc_filter_ipv4addr *filter) {
 	filter->active = 0;
-	filter->typeinfo_must_have = 0;
-	filter->typeinfo_may_not_have = 0;
+
+	filter->filter_typeinfo.active = 0;
+	filter->filter_typeinfo.typeinfo_must_have = 0;
+	filter->filter_typeinfo.typeinfo_may_not_have = 0;
+
+	libipv6calc_filter_clear_db_cc(&filter->filter_db_cc);
+	libipv6calc_filter_clear_db_asn(&filter->filter_db_asn);
+	libipv6calc_filter_clear_db_registry(&filter->filter_db_registry);
+
+        filter->filter_addr.active = 0;
+        filter->filter_addr.addr_must_have_max = 0;
+        filter->filter_addr.addr_may_not_have_max = 0;
+
 	return;
 };
 
@@ -896,9 +941,14 @@ void ipv4addr_filter_clear(s_ipv6calc_filter_ipv4addr *filter) {
  * ret: 0:found 1:skip 2:problem
  */
 int ipv4addr_filter_parse(s_ipv6calc_filter_ipv4addr *filter, const char *token) {
-	int i, result = 1, negate = 0, offset = 0;
+	int i, result = 1, negate = 0, offset = 0, r;
 	const char *prefix = "ipv4";
 	const char *prefixdot = "ipv4.";
+	const char *prefixdbdot = "db.";
+	const char *prefixaddreq = "addr=";
+	ipv6calc_ipv4addr ipv4addr;
+	char resultstring[NI_MAXHOST];
+	int db = 0, addr = 0;
 
 	if (token == NULL) {
 		return (result);
@@ -913,13 +963,15 @@ int ipv4addr_filter_parse(s_ipv6calc_filter_ipv4addr *filter, const char *token)
 		offset += 1;
 	};
 
+	// typeinfo
 	if (strcmp(token + offset, prefix) == 0) {
 		/* any */
 		if (negate == 1) {
-			filter->typeinfo_may_not_have = ~IPV4_ADDR_ANY;
+			filter->filter_typeinfo.typeinfo_may_not_have = ~IPV4_ADDR_ANY;
 		} else {
-			filter->typeinfo_must_have = IPV4_ADDR_ANY;
+			filter->filter_typeinfo.typeinfo_must_have = IPV4_ADDR_ANY;
 		};
+		filter->filter_typeinfo.active = 1;
 		filter->active = 1;
 		result = 0;
 		goto END_ipv4addr_filter_parse;
@@ -929,26 +981,98 @@ int ipv4addr_filter_parse(s_ipv6calc_filter_ipv4addr *filter, const char *token)
 		offset += strlen(prefixdot);
 		result = 2; /* token with prefix, result into problem if not found */
 
+		DEBUGPRINT_WA(DEBUG_libipv4addr, "token with prefix, suffix: %s", token + offset);
+	};
+
+	if (strncmp(token + offset, prefixaddreq, strlen(prefixaddreq)) == 0) {
+		/* prefixaddr with = found */
+		DEBUGPRINT_WA(DEBUG_libipv4addr, "found 'addr=' prefix in token: %s", token);
+		addr = 1;
+		offset += strlen(prefixaddreq);
+
+	} else if (strncmp(token + offset, prefixdbdot, strlen(prefixdbdot)) == 0) {
+		/* prefixdb with dot found */
+		DEBUGPRINT_WA(DEBUG_libipv4addr, "found 'db.' prefix in token: %s", token);
+		db = 1;
+
 	} else if (strstr(token, ".") != NULL) {
 		/* other prefix */
 		DEBUGPRINT_WA(DEBUG_libipv4addr, "prefix did not match: %s", token + offset);
 		return(1);
 	};
 
-	for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv4addrtypestrings); i++ ) {
-		DEBUGPRINT_WA(DEBUG_libipv4addr, "check token against: %s", ipv6calc_ipv4addrtypestrings[i].token);
 
-		if (strcmp(ipv6calc_ipv4addrtypestrings[i].token, token + offset) == 0) {
-			DEBUGPRINT_WA(DEBUG_libipv4addr, "token match: %s", ipv6calc_ipv4addrtypestrings[i].token);
+	if ((db == 0) && (addr == 0)) {
+		// typeinfo token
+		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv4addrtypestrings); i++ ) {
+			DEBUGPRINT_WA(DEBUG_libipv4addr, "check token against: %s", ipv6calc_ipv4addrtypestrings[i].token);
+
+			if (strcmp(ipv6calc_ipv4addrtypestrings[i].token, token + offset) == 0) {
+				DEBUGPRINT_WA(DEBUG_libipv4addr, "token match: %s", ipv6calc_ipv4addrtypestrings[i].token);
+
+				if (negate == 1) {
+					filter->filter_typeinfo.typeinfo_may_not_have |= ipv6calc_ipv4addrtypestrings[i].number;
+				} else {
+					filter->filter_typeinfo.typeinfo_must_have |= ipv6calc_ipv4addrtypestrings[i].number;
+				};
+				filter->filter_typeinfo.active = 1;
+				filter->active = 1;
+				result = 0;
+				break;
+			};
+		};
+	};
+
+	if (db == 1) {
+		// DB CC filter
+		r = libipv6calc_db_cc_filter_parse(&filter->filter_db_cc, token + offset, negate);
+		if (r == 0) {
+			result = 0;
+			filter->active = 1;
+		};
+
+		// DB ASN filter
+		r = libipv6calc_db_asn_filter_parse(&filter->filter_db_asn, token + offset, negate);
+		if (r == 0) {
+			result = 0;
+			filter->active = 1;
+		};
+
+		// DB Registry filter
+		r = libipv6calc_db_registry_filter_parse(&filter->filter_db_registry, token + offset, negate);
+		if (r == 0) {
+			result = 0;
+			filter->active = 1;
+		};
+	};
+
+	if (addr == 1) {
+		DEBUGPRINT_WA(DEBUG_libipv4addr, "try to parse IPv4 address: %s", token + offset);
+		r = addr_to_ipv4addrstruct(token + offset, resultstring, sizeof(resultstring), &ipv4addr);
+		if (r == 0) {
+			DEBUGPRINT_WA(DEBUG_libipv4addr, "successfully parsed IPv4 address: %s", token + offset);
 
 			if (negate == 1) {
-				filter->typeinfo_may_not_have |= ipv6calc_ipv4addrtypestrings[i].number;
+				if (filter->filter_addr.addr_may_not_have_max < IPV6CALC_FILTER_IPV4ADDR) {
+					ipv4addr_copy(&filter->filter_addr.ipv4addr_may_not_have[filter->filter_addr.addr_may_not_have_max], &ipv4addr);
+        				filter->filter_addr.addr_may_not_have_max++;
+					filter->filter_addr.active = 1;
+					filter->active = 1;
+					result = 0;
+				} else {
+					ERRORPRINT_WA("filter token 'addr=' maxmimum reached for 'may not have': %d", filter->filter_addr.addr_may_not_have_max);
+				};
 			} else {
-				filter->typeinfo_must_have |= ipv6calc_ipv4addrtypestrings[i].number;
+				if (filter->filter_addr.addr_must_have_max < IPV6CALC_FILTER_IPV4ADDR) {
+					ipv4addr_copy(&filter->filter_addr.ipv4addr_must_have[filter->filter_addr.addr_must_have_max], &ipv4addr); 
+        				filter->filter_addr.addr_must_have_max++;
+					filter->filter_addr.active = 1;
+					filter->active = 1;
+					result = 0;
+				} else {
+					ERRORPRINT_WA("filter token 'addr=' maxmimum reached for 'must have': %d", filter->filter_addr.addr_must_have_max);
+				};
 			};
-			filter->active = 1;
-			result = 0;
-			break;
 		};
 	};
 
@@ -958,10 +1082,63 @@ int ipv4addr_filter_parse(s_ipv6calc_filter_ipv4addr *filter, const char *token)
 	};
 
 END_ipv4addr_filter_parse:
-	DEBUGPRINT_WA(DEBUG_libipv4addr, "filter 'must_have'   : 0x%08x", filter->typeinfo_must_have);
-	DEBUGPRINT_WA(DEBUG_libipv4addr, "filter 'may_not_have': 0x%08x", filter->typeinfo_may_not_have);
-	DEBUGPRINT_WA(DEBUG_libipv4addr, "filter 'active': %d", filter->active);
+	return (result);
+};
 
+
+/*
+ * check filter IPv4
+ *
+ * in : *filter    = filter structure
+ * ret: 0:ok 1:problem
+ */
+int ipv4addr_filter_check(s_ipv6calc_filter_ipv4addr *filter) {
+	int result = 0, r, i;
+	char resultstring[NI_MAXHOST];
+
+	DEBUGPRINT_WA(DEBUG_libipv4addr, "ipv4 filter general active         : %d", filter->active);
+
+	DEBUGPRINT_WA(DEBUG_libipv4addr, "ipv4 filter 'typeinfo' active      : %d", filter->filter_typeinfo.active);
+	if (filter->filter_typeinfo.active > 0) {
+		DEBUGPRINT_WA(DEBUG_libipv4addr, "ipv4 filter 'typeinfo/must_have'   : 0x%08x", filter->filter_typeinfo.typeinfo_must_have);
+		DEBUGPRINT_WA(DEBUG_libipv4addr, "ipv4 filter 'typeinfo/may_not_have': 0x%08x", filter->filter_typeinfo.typeinfo_may_not_have);
+	};
+
+	DEBUGPRINT_WA(DEBUG_libipv4addr, "ipv4 filter 'addr' active          : %d", filter->filter_addr.active);
+	if (filter->filter_addr.active > 0) {
+		if (filter->filter_addr.addr_must_have_max > 0) {
+			for (i = 0; i < filter->filter_addr.addr_must_have_max; i++) {
+				libipv4addr_ipv4addrstruct_to_string(&filter->filter_addr.ipv4addr_must_have[i], resultstring, sizeof(resultstring), 0);
+				DEBUGPRINT_WA(DEBUG_libipv4addr, "ipv4 filter 'addr/must_have'       : %s", resultstring);
+			};
+		};
+		if (filter->filter_addr.addr_may_not_have_max > 0) {
+			for (i = 0; i < filter->filter_addr.addr_may_not_have_max; i++) {
+				libipv4addr_ipv4addrstruct_to_string(&filter->filter_addr.ipv4addr_may_not_have[i], resultstring, sizeof(resultstring), 0);
+				DEBUGPRINT_WA(DEBUG_libipv4addr, "ipv4 filter 'addr/may_not_have'    : %s", resultstring);
+			};
+		};
+	};
+
+	DEBUGPRINT_WA(DEBUG_libipv4addr, "ipv4 filter 'db.cc' active         : %d", filter->filter_db_cc.active);
+	if (filter->filter_db_cc.active > 0) {
+		r = libipv6calc_db_cc_filter_check(&filter->filter_db_cc, IPV6CALC_PROTO_IPV4);
+		if (r > 0) { result = 1; };
+	};
+
+	DEBUGPRINT_WA(DEBUG_libipv4addr, "ipv4 filter 'db.asn' active        : %d", filter->filter_db_asn.active);
+	if (filter->filter_db_asn.active > 0) {
+		r = libipv6calc_db_asn_filter_check(&filter->filter_db_asn, IPV6CALC_PROTO_IPV4);
+		if (r > 0) { result = 1; };
+	};
+
+	DEBUGPRINT_WA(DEBUG_libipv4addr, "ipv4 filter 'db.registry' active   : %d", filter->filter_db_registry.active);
+	if (filter->filter_db_registry.active > 0) {
+		r = libipv6calc_db_registry_filter_check(&filter->filter_db_registry, IPV6CALC_PROTO_IPV4);
+		if (r > 0) { result = 1; };
+	};
+
+//END_ipv4addr_filter_check:
 	return (result);
 };
 
@@ -975,6 +1152,7 @@ END_ipv4addr_filter_parse:
  */
 int ipv4addr_filter(const ipv6calc_ipv4addr *ipv4addrp, const s_ipv6calc_filter_ipv4addr *filter) {
 	uint32_t typeinfo;
+	int result = 0, r, i;
 
 	if (filter->active == 0) {
 		DEBUGPRINT_NA(DEBUG_libipv4addr, "no filter active (SKIP)");
@@ -983,18 +1161,83 @@ int ipv4addr_filter(const ipv6calc_ipv4addr *ipv4addrp, const s_ipv6calc_filter_
 
 	DEBUGPRINT_NA(DEBUG_libipv4addr, "start");
 
-	/* get type */
-	typeinfo = ipv4addr_gettype(ipv4addrp);
+	if (filter->filter_typeinfo.active > 0) {
+		/* get type */
+		typeinfo = ipv4addr_gettype(ipv4addrp);
 
-	DEBUGPRINT_WA(DEBUG_libipv4addr, "compare typeinfo against must_have: 0x%08x/0x%08x", typeinfo, filter->typeinfo_must_have);
+		DEBUGPRINT_WA(DEBUG_libipv4addr, "compare typeinfo against must_have: 0x%08x/0x%08x", typeinfo, filter->filter_typeinfo.typeinfo_must_have);
 
-	if ((typeinfo & filter->typeinfo_must_have) == filter->typeinfo_must_have) {
-		if ((typeinfo & filter->typeinfo_may_not_have) == 0) {
-			return (0);
+		if ((typeinfo & filter->filter_typeinfo.typeinfo_must_have) != filter->filter_typeinfo.typeinfo_must_have) {
+			/* no match */
+			result = 1;
+		} else {
+			if ((typeinfo & filter->filter_typeinfo.typeinfo_may_not_have) != 0) {
+				result = 1;
+			};
 		};
 	};
 
-	return (1);
+	if (filter->filter_addr.active > 0) {
+		if (filter->filter_addr.addr_must_have_max > 0) {
+			r = 0;
+			for (i = 0; i < filter->filter_addr.addr_must_have_max; i++) {
+				if (ipv4addr_compare(&filter->filter_addr.ipv4addr_must_have[i], ipv4addrp, 0) == 0) {
+					/* match must_have */
+					r = 1;
+				};
+			};
+			if (r == 0) {
+				/* no match */
+				result = 1;
+			};
+		};
+		if (filter->filter_addr.addr_may_not_have_max > 0) {
+			r = 0;
+			for (i = 0; i < filter->filter_addr.addr_may_not_have_max; i++) {
+				if (ipv4addr_compare(&filter->filter_addr.ipv4addr_may_not_have[i], ipv4addrp, 0) == 0) {
+					/* match may_not_have */
+					r = 1;
+				};
+			};
+			if (r == 1) {
+				/* match may_not_have*/
+				result = 1;
+			};
+		};
+	};
+
+	if (filter->filter_db_cc.active > 0) {
+		uint16_t cc_index = libipv4addr_cc_index_by_addr(ipv4addrp, NULL);
+
+		if (libipv6calc_db_cc_filter(cc_index, &filter->filter_db_cc) > 0) {
+			/* no match */
+			result = 1;
+		};
+	};
+
+	if (filter->filter_db_asn.active > 0) {
+		uint32_t asn = libipv4addr_as_num32_by_addr(ipv4addrp);
+
+		if (filter->filter_db_asn.active > 0) {
+			if (libipv6calc_db_asn_filter(asn, &filter->filter_db_asn) > 0) {
+				/* no match */
+				result = 1;
+			};
+		};
+	};
+
+	if (filter->filter_db_registry.active > 0) {
+		int registry = libipv4addr_registry_num_by_addr(ipv4addrp);
+
+		if (filter->filter_db_registry.active > 0) {
+			if (libipv6calc_db_registry_filter(registry, &filter->filter_db_registry) > 0) {
+				/* no match */
+				result = 1;
+			};
+		};
+	};
+
+	return (result);
 };
 
 
