@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc/lib
  * File       : libipv4addr.h
- * Version    : $Id: libipv4addr.h,v 1.38 2014/09/24 09:07:58 ds6peter Exp $
- * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
+ * Version    : $Id: libipv4addr.h,v 1.41 2015/05/07 06:19:27 ds6peter Exp $
+ * Copyright  : 2002-2015 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  * License    : GNU GPL v2
  *
  * Information:
@@ -26,13 +26,24 @@ typedef struct {
 	int flag_valid;			/* address structure filled */
 } ipv6calc_ipv4addr;
 
+/* IPv4 Address filter structure */
+typedef struct {
+        int active;
+        int addr_must_have_max;
+        int addr_may_not_have_max;
+        ipv6calc_ipv4addr ipv4addr_must_have[IPV6CALC_FILTER_IPV4ADDR];
+        ipv6calc_ipv4addr ipv4addr_may_not_have[IPV6CALC_FILTER_IPV6ADDR];
+} s_ipv6calc_filter_addr_ipv4;
 
 /* IPv4 filter structure */
 typedef struct {
-	int active;	
-	uint32_t typeinfo_must_have;
-	uint32_t typeinfo_may_not_have;
-	/* others coming next */
+	int active;
+	s_ipv6calc_filter_typeinfo    filter_typeinfo;
+	s_ipv6calc_filter_db_cc       filter_db_cc;        // Country Code filter
+	s_ipv6calc_filter_db_asn      filter_db_asn;       // Autonomous System Number filter
+	s_ipv6calc_filter_db_registry filter_db_registry;  // Registry filter
+	s_ipv6calc_filter_addr_ipv4   filter_addr;         // IPv4 Address filter
+	/* others may come next */
 } s_ipv6calc_filter_ipv4addr;
 
 
@@ -134,11 +145,11 @@ typedef struct {
 
 
 /* prototypes */
-extern uint8_t  ipv4addr_getoctet(const ipv6calc_ipv4addr *ipv4addrp, const unsigned int numoctett);
+extern uint8_t  ipv4addr_getoctet(const ipv6calc_ipv4addr *ipv4addrp, const unsigned int numoctet);
 extern uint16_t ipv4addr_getword(const ipv6calc_ipv4addr *ipv4addrp, const unsigned int numword);
 extern uint32_t ipv4addr_getdword(const ipv6calc_ipv4addr *ipv4addrp);
 
-extern void ipv4addr_setoctet(ipv6calc_ipv4addr *ipv4addrp, const unsigned int numocett, const uint8_t value);
+extern void ipv4addr_setoctet(ipv6calc_ipv4addr *ipv4addrp, const unsigned int numoctet, const uint8_t value);
 extern void ipv4addr_setword(ipv6calc_ipv4addr *ipv4addrp, const unsigned int numword, const uint16_t value);
 extern void ipv4addr_setdword(ipv6calc_ipv4addr *ipv4addrp, const uint32_t value);
 
@@ -146,6 +157,8 @@ extern void ipv4addr_clear(ipv6calc_ipv4addr *ipv4addrp);
 extern void ipv4addr_clearall(ipv6calc_ipv4addr *ipv4addrp);
 extern void ipv4addr_copy(ipv6calc_ipv4addr *ipv4addrp_dst, const ipv6calc_ipv4addr *ipv4addrp_src);
 
+extern int ipv4addr_compare(const ipv6calc_ipv4addr *ipv4addrp1, const ipv6calc_ipv4addr *ipv4addrp2, const uint16_t compare_flags);
+
 extern uint32_t ipv4addr_gettype(const ipv6calc_ipv4addr *ipv4addrp);
 
 extern int addr_to_ipv4addrstruct(const char *addrstring, char *resultstring, const size_t resultstring_length, ipv6calc_ipv4addr *ipv4addrp);
@@ -164,6 +177,7 @@ extern uint16_t ipv4addr_anonymized_get_cc_index(const ipv6calc_ipv4addr *ipv4ad
 
 extern int ipv4addr_filter(const ipv6calc_ipv4addr *ipv4addrp, const s_ipv6calc_filter_ipv4addr *filter);
 extern int ipv4addr_filter_parse(s_ipv6calc_filter_ipv4addr *filter, const char *token);
+extern int ipv4addr_filter_check(s_ipv6calc_filter_ipv4addr *filter);
 extern void ipv4addr_filter_clear(s_ipv6calc_filter_ipv4addr *filter);
 
 extern uint16_t libipv4addr_cc_index_by_addr(const ipv6calc_ipv4addr *ipv4addrp, unsigned int *data_source_ptr);
