@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : libipv6addr.h
- * Version    : $Id: libipv6addr.h,v 1.84 2014/10/07 20:25:23 ds6peter Exp $
+ * Version    : $Id: libipv6addr.h,v 1.90 2015/05/30 16:42:32 ds6peter Exp $
  * Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  *
  * Information:
@@ -164,24 +164,37 @@
 /* IPv6 address storage structure */
 typedef struct {
 	struct in6_addr in6_addr;	/* in6_addr structure */
-	uint8_t prefixlength;		/* prefix length (0-128) 8 bit*/
+	uint8_t prefixlength;		/* prefix length (0-128) 8 bit */
 	int flag_prefixuse;		/* =1 prefix length in use */
 	uint32_t scope;			/* address typeinfo/scope */
+	uint32_t typeinfo2;		/* address typeinfo2 */
 	uint8_t bit_start;		/* start of bit */
 	uint8_t bit_end;		/* end of bit */
 	int flag_startend_use;		/* =1 start or end of bit in use */
 	int flag_valid;			/* address structure filled */
 	char scopeid[IPV6CALC_SCOPEID_STRING_MAX];	/* scope ID value */
 	int flag_scopeid;		/* =1: scope ID value set */
+	uint8_t prefix2length;		/* prefix 2 length (0-128) 8 bit (usage depends on typeinfo/typeinfo2)*/
 } ipv6calc_ipv6addr;
 
+/* IPv6 Address filter structure */
+typedef struct {
+        int active;
+        int addr_must_have_max;
+        int addr_may_not_have_max;
+        ipv6calc_ipv6addr ipv6addr_must_have[IPV6CALC_FILTER_IPV4ADDR];
+        ipv6calc_ipv6addr ipv6addr_may_not_have[IPV6CALC_FILTER_IPV6ADDR];
+} s_ipv6calc_filter_addr_ipv6;
 
 /* IPv6 filter structure */
 typedef struct {
 	int active;
-	uint32_t typeinfo_must_have;
-	uint32_t typeinfo_may_not_have;
-	/* others coming next */
+	s_ipv6calc_filter_typeinfo    filter_typeinfo;
+	s_ipv6calc_filter_db_cc       filter_db_cc;        // Country Code filter
+	s_ipv6calc_filter_db_asn      filter_db_asn;       // Autonomous System Number filter
+	s_ipv6calc_filter_db_registry filter_db_registry;  // Registry filter
+	s_ipv6calc_filter_addr_ipv6   filter_addr;         // IPv6 Address filter
+	/* others may come next */
 } s_ipv6calc_filter_ipv6addr;
 
 
@@ -284,8 +297,15 @@ typedef struct {
 #define IPV6_ADDR_HAS_PUBLIC_IPV4_IN_IID	(IPV6_NEW_ADDR_NAT64 | IPV6_NEW_ADDR_TEREDO | IPV6_ADDR_COMPATv4 | IPV6_ADDR_MAPPED | IPV6_NEW_ADDR_6TO4_MICROSOFT)
 #define IPV6_ADDR_HAS_PUBLIC_IPV4		(IPV6_ADDR_HAS_PUBLIC_IPV4_IN_IID | IPV6_ADDR_HAS_PUBLIC_IPV4_IN_PREFIX)
 
+#define IPV6_ADDR_GLOBAL			(IPV6_NEW_ADDR_PRODUCTIVE)
+
+// typeinfo2
+#define IPV6_ADDR_TYPE2_6RD			(uint32_t) 0x00000001U	/* IPv6 Rapid Deployment address (RFC5569), not autodetectable (triggered by --6rd_prefixlength) */
+
+// IPv4 address extractor selector
 #define IPV6_ADDR_SELECT_IPV4_DEFAULT		0
 #define IPV6_ADDR_SELECT_IPV4_TEREDO_SERVER	1
+#define IPV6_ADDR_SELECT_IPV4_PREFIX2_LENGTH	2
 
 /* text representations */
 /*@unused@*/ static const s_type ipv6calc_ipv6addrtypestrings[] = {
@@ -324,6 +344,10 @@ typedef struct {
 	{ IPV6_ADDR_IID_32_63_HAS_IPV4	, "iid-includes-ipv4" }
 };
 
+/* text representations */
+/*@unused@*/ static const s_type ipv6calc_ipv6addr_type2_strings[] = {
+	{ IPV6_ADDR_TYPE2_6RD		, "6rd" },
+};
 
 /* Registries */
 #include "libipv6calc.h"
@@ -357,7 +381,7 @@ extern uint8_t  ipv6addr_getoctet(const ipv6calc_ipv6addr *ipv6addrp, const unsi
 extern uint16_t ipv6addr_getword(const ipv6calc_ipv6addr *ipv6addrp, const unsigned int numword);
 extern uint32_t ipv6addr_getdword(const ipv6calc_ipv6addr *ipv6addrp, const unsigned int numdword);
 
-extern void ipv6addr_setoctet(ipv6calc_ipv6addr *ipv6addrp, const unsigned int numocett, unsigned int value);
+extern void ipv6addr_setoctet(ipv6calc_ipv6addr *ipv6addrp, const unsigned int numoctet, unsigned int value);
 extern void ipv6addr_setword(ipv6calc_ipv6addr *ipv6addrp, const unsigned int numword, unsigned int value);
 extern void ipv6addr_setdword(ipv6calc_ipv6addr *ipv6addrp, const unsigned int numdword, unsigned int value);
 
@@ -365,7 +389,10 @@ extern void ipv6addr_clear(ipv6calc_ipv6addr *ipv6addrp);
 extern void ipv6addr_clearall(ipv6calc_ipv6addr *ipv6addrp);
 extern void ipv6addr_copy(ipv6calc_ipv6addr *ipv6addrp_dst, const ipv6calc_ipv6addr *ipv6addrp_src);
 
+extern int ipv6addr_compare(const ipv6calc_ipv6addr *ipv6addrp1, const ipv6calc_ipv6addr *ipv6addrp2, const uint16_t compare_flags);
+
 extern uint32_t ipv6addr_gettype(const ipv6calc_ipv6addr *ipv6addrp);
+extern uint32_t ipv6addr_gettype2(const ipv6calc_ipv6addr *ipv6addrp);
 
 extern int  addr_to_ipv6addrstruct(const char *addrstring, char *resultstring, const size_t resultstring_length, ipv6calc_ipv6addr *ipv6addrp);
 extern int  addrliteral_to_ipv6addrstruct(const char *addrstring, char *resultstring, const size_t resultstring_length, ipv6calc_ipv6addr *ipv6addrp);
@@ -390,6 +417,7 @@ extern int ipv6addr_iidrandomdetection(const ipv6calc_ipv6addr *ipv6addrp, s_iid
 
 extern int  ipv6addr_filter(const ipv6calc_ipv6addr *ipv6addrp, const s_ipv6calc_filter_ipv6addr *filter);
 extern int  ipv6addr_filter_parse(s_ipv6calc_filter_ipv6addr *filter, const char *token);
+extern int  ipv6addr_filter_check(s_ipv6calc_filter_ipv6addr *filter);
 extern void ipv6addr_filter_clear(s_ipv6calc_filter_ipv6addr *filter);
 
 extern int  libipv6addr_get_included_ipv4addr(const ipv6calc_ipv6addr *ipv6addrp, ipv6calc_ipv4addr *ipv4addrp, const int selector);
