@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc/lib
  * File       : libipv6calc.c
- * Version    : $Id: libipv6calc.c,v 1.39 2014/09/24 09:07:58 ds6peter Exp $
- * Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: libipv6calc.c,v 1.45 2015/05/28 20:23:23 ds6peter Exp $
+ * Copyright  : 2001-2015 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Function library for some tools
@@ -13,6 +13,8 @@
 #include <stdlib.h>
 #include <ctype.h>
 
+#include "config.h"
+
 #include "ipv6calctypes.h"
 #include "libipv6calc.h"
 #include "libipv6calcdebug.h"
@@ -213,8 +215,10 @@ uint32_t libipv6calc_autodetectinput(const char *string) {
 		} else DEBUGPRINT_WA(DEBUG_libipv6calc, " check FORMAT_base85 not successful, result: %s", resultstring);
 	};
 	
-	if (length >= 7 && length <= 15 && numdots == 3 && numcolons == 0 && numdigits == numxdigits && numdigits >= 4 && numdigits <= 12 && numslashes <= 1 && (numdots + numdigits + numslashes) == length) {
-		/* IPv4: ddd.ddd.ddd.ddd */
+	if (((length >= 7 && length <= 15 && numdots == 3 && numcolons == 0 && numdigits == numxdigits && numdigits >= 4 && numdigits <= 12 && numslashes == 0 )
+	    || ((length >= 9 && length <= 18 && numdots == 3 && numcolons == 0 && numdigits == numxdigits && numdigits >= 5 && numdigits <= 14 && numslashes == 1)))
+	    && (numdots + numdigits + numslashes) == length) {
+		/* IPv4: d{1-3}.d{1-3}.d{1-3}.d{1-3} or d{1-3}.d{1-3}.d{1-3}.d{1-3}/d{1-2} */
 		type = FORMAT_ipv4addr;
 		goto END_libipv6calc_autodetectinput;
 	};
@@ -411,7 +415,7 @@ END_libipv6calc_autodetectinput:
 
 
 /*
- * clear filter master address
+ * clear filter master structure
  *
  * in : *filter    = filter structure
  */
@@ -422,6 +426,68 @@ void libipv6calc_filter_clear(s_ipv6calc_filter_master *filter_master) {
 	return;
 };
 
+/*
+ * clear filter sub structure db_cc
+ *
+ * in : *filter    = filter structure
+ */
+void libipv6calc_filter_clear_db_cc(s_ipv6calc_filter_db_cc *filter_db_cc) {
+	int i;
+
+	filter_db_cc->active = 0;
+	filter_db_cc->cc_must_have_max = 0;
+	filter_db_cc->cc_may_not_have_max = 0;
+
+	for (i = 0; i < IPV6CALC_FILTER_DB_CC_MAX; i++) {
+		filter_db_cc->cc_must_have[i] = 0;
+		filter_db_cc->cc_may_not_have[i] = 0;
+	};
+
+	return;
+};
+
+
+/*
+ * clear filter sub structure db_asn
+ *
+ * in : *filter    = filter structure
+ */
+void libipv6calc_filter_clear_db_asn(s_ipv6calc_filter_db_asn *filter_db_asn) {
+	int i;
+
+	filter_db_asn->active = 0;
+	filter_db_asn->asn_must_have_max = 0;
+	filter_db_asn->asn_may_not_have_max = 0;
+
+	for (i = 0; i < IPV6CALC_FILTER_DB_ASN_MAX; i++) {
+		filter_db_asn->asn_must_have[i] = 0;
+		filter_db_asn->asn_may_not_have[i] = 0;
+	};
+
+	return;
+};
+
+
+/*
+ * clear filter sub structure db_registry
+ *
+ * in : *filter    = filter structure
+ */
+void libipv6calc_filter_clear_db_registry(s_ipv6calc_filter_db_registry *filter_db_registry) {
+	int i;
+
+	filter_db_registry->active = 0;
+	filter_db_registry->registry_must_have_max = 0;
+	filter_db_registry->registry_may_not_have_max = 0;
+
+	for (i = 0; i < IPV6CALC_FILTER_DB_REGISTRY_MAX; i++) {
+		filter_db_registry->registry_must_have[i] = 0;
+		filter_db_registry->registry_may_not_have[i] = 0;
+	};
+
+	return;
+};
+
 
 /*
  * function parses ipv6calc filter expression
@@ -436,6 +502,8 @@ int libipv6calc_filter_parse(const char *expression, s_ipv6calc_filter_master *f
 	ptrptr = &cptr;
 	int r, token_used, result = 0;
 
+	DEBUGPRINT_WA(DEBUG_libipv6calc, "called with: %s", expression);
+
 	snprintf(tempstring, sizeof(tempstring), "%s", expression);
 
 	/* split expression */
@@ -448,7 +516,7 @@ int libipv6calc_filter_parse(const char *expression, s_ipv6calc_filter_master *f
 			token_used = 1;
 		} else if (r == 2) {
 			result = 1;
-			fprintf(stderr, "Unrecognized filter token: %s\n", charptr);
+			ERRORPRINT_WA("Unrecognized filter token (ipv4.xxx): %s", charptr);
 		};
 
 		r = ipv6addr_filter_parse(&filter_master->filter_ipv6addr, charptr);
@@ -456,15 +524,15 @@ int libipv6calc_filter_parse(const char *expression, s_ipv6calc_filter_master *f
 			token_used = 1;
 		} else if (r == 2) {
 			result = 1;
-			fprintf(stderr, "Unrecognized filter token: %s\n", charptr);
+			ERRORPRINT_WA("Unrecognized filter token (ipv6.xxx): %s", charptr);
 		};
 
-		// r += macaddr_filter_parse(&filter_macaddr, charptr);
+		// r += macaddr_filter_parse(&filter_macaddr, charptr); // missing implementation
 
 		/* overall check */
-		if (token_used == 0) {
+		if ((token_used == 0) && (result != 1)) {
 			result = 1;
-			fprintf(stderr, "Unrecognized filter token: %s\n", charptr);
+			ERRORPRINT_WA("Unrecognized filter token (general): %s", charptr);
 		};
 
 		charptr = strtok_r(NULL, ",", ptrptr);
@@ -474,6 +542,35 @@ int libipv6calc_filter_parse(const char *expression, s_ipv6calc_filter_master *f
 };
 
 
+/*
+ * function checks ipv6calc filter expression
+ *
+ * in: master filter structure
+ * ret: success
+ */
+int libipv6calc_filter_check(s_ipv6calc_filter_master *filter_master) {
+	int result = 0, r;
+
+	DEBUGPRINT_NA(DEBUG_libipv6calc, "called");
+
+	r = ipv4addr_filter_check(&filter_master->filter_ipv4addr);
+	if (r > 0) {
+		result = 1;
+	};
+
+	r = ipv6addr_filter_check(&filter_master->filter_ipv6addr);
+	if (r > 0) {
+		result = 1;
+	};
+
+	if (result == 1) {
+		ERRORPRINT_NA("filter check failed");
+	};
+
+	return (result);
+};
+
+
 /*
  * return proper anonymization set by name
  *
@@ -617,3 +714,32 @@ int libipv6calc_bitcount_uint32_t(const uint32_t value) {
 	};
 	return(count);
 };
+
+/*
+ * return library version numeric
+ */
+uint32_t libipv6calc_lib_version_numeric(void) {
+	return(IPV6CALC_PACKAGE_VERSION_NUMERIC);
+}; 
+
+/*
+ * return library version as string
+ */
+const char *libipv6calc_lib_version_string(void) {
+	return(IPV6CALC_PACKAGE_VERSION_STRING);
+
+};
+
+/*
+ * return API version numeric
+ */
+uint32_t libipv6calc_api_version_numeric(void) {
+	return(IPV6CALC_API_VERSION_NUMERIC);
+};
+
+/*
+ * return API version as string
+ */
+const char *libipv6calc_api_version_string(void) {
+	return(IPV6CALC_API_VERSION_STRING);
+};
