@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc/lib
  * File       : libipv6calcdebug.h
- * Version    : $Id: libipv6calcdebug.h,v 1.19 2014/04/26 13:03:56 ds6peter Exp $
+ * Version    : $Id: libipv6calcdebug.h,v 1.23 2014/10/07 20:25:23 ds6peter Exp $
  * Copyright  : 2002-2013 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -37,6 +37,7 @@
 #define DEBUG_libeui64					0x00008000l
 
 #define DEBUG_libmac					0x00010000l
+#define DEBUG_libipaddr					0x00020000l
 
 #define DEBUG_libipv6calc_db_wrapper			0x00100000l
 #define DEBUG_libipv6calc_db_wrapper_GeoIP		0x00200000l
@@ -46,13 +47,17 @@
 #define DEBUG_libipv6addr_iidrandomdetection		0x01000000l
 #define DEBUG_libipv6addr_anonymization_unknown_break	0x02000000l
 
+#define DEBUG_libipv6calc_db_wrapper_DBIP		0x10000000l
+#define DEBUG_libipv6calc_db_wrapper_External		0x20000000l
+#define DEBUG_libipv6calc_db_wrapper_BuiltIn		0x40000000l
+
 /* debug print with args */
 #define DEBUGPRINT_WA(d, t, ...)	\
 	if ((ipv6calc_debug & (d)) != 0) { \
 		if (ipv6calc_debug == DEBUG_ipv6calc_ALL) { \
-			fprintf(stderr, "%s/%s[0x%08lx]: " t "\n", __FILE__, __func__, d, __VA_ARGS__); \
+			fprintf(stderr, "%s/%s:%d[0x%08lx]: " t "\n", __FILE__, __func__, __LINE__, d, __VA_ARGS__); \
 		} else { \
-			fprintf(stderr, "%s/%s: " t "\n", __FILE__, __func__, __VA_ARGS__); \
+			fprintf(stderr, "%s/%s:%d: " t "\n", __FILE__, __func__, __LINE__, __VA_ARGS__); \
 		}; \
 	};
 
@@ -60,19 +65,19 @@
 #define DEBUGPRINT_NA(d, t)		\
 	if ((ipv6calc_debug & (d)) != 0) { \
 		if (ipv6calc_debug == DEBUG_ipv6calc_ALL) { \
-			fprintf(stderr, "%s/%s[0x%08lx]: " t "\n", __FILE__, __func__, d); \
+			fprintf(stderr, "%s/%s:%d[0x%08lx]: " t "\n", __FILE__, __func__, __LINE__, d); \
 		} else { \
-			fprintf(stderr, "%s/%s: " t "\n", __FILE__, __func__); \
+			fprintf(stderr, "%s/%s:%d: " t "\n", __FILE__, __func__, __LINE__); \
 		}; \
 	};
 
 /* error print with args */
 #define ERRORPRINT_WA(t, ...)	\
-	fprintf(stderr, "%s/%s: " t "\n", __FILE__, __func__, __VA_ARGS__);
+	fprintf(stderr, "%s/%s:%d: " t "\n", __FILE__, __func__, __LINE__, __VA_ARGS__);
 
 /* error print no args */
 #define ERRORPRINT_NA(t)		\
-	fprintf(stderr, "%s/%s: " t "\n", __FILE__, __func__);
+	fprintf(stderr, "%s/%s:%d: " t "\n", __FILE__, __func__, __LINE__);
 
 /* begin/end of debug section */
 #define DEBUGSECTION_BEGIN(d)	if ((ipv6calc_debug & (d)) != 0) {
